//////////////////////////////////////////////////////////////////////
//
//  APP.CH
//
//  Copyright:
//      Alaska Software, (c) 1998-2023. All rights reserved.         
//  
//  Contents:
//      Constants used for Application parts
//   
//////////////////////////////////////////////////////////////////////


#ifndef  _APP_CH
#include "Xbp.ch"

******************************************************************************
* All application parts require XPPUI2.LIB
******************************************************************************
#pragma Library( "XPPUI2.LIB" )

******************************************************************************
* Return values for database OPeration codeblocks of APPs 
******************************************************************************
// proceed with operation
#define  APPOP_PROCEED                 0  
// abort operation
#define  APPOP_IGNORE                  1  
// operation was done within codeblock already, ignore own method
#define  APPOP_REFRESH                 2  


******************************************************************************
* Constants used to suppress default controls of the AppEdit() dialog
* Add constants to suppress multiple controls and use the NOACTION option
* of the APP? command
******************************************************************************
#define  APPACTION_DEFAULT              0
#define  APPACTION_NOGOTOP              1
#define  APPACTION_NOPREVIOUS           2
#define  APPACTION_NONEXT               4
#define  APPACTION_NOGOBOTTOM           8
#define  APPACTION_NOINSERT            16
#define  APPACTION_NODELETE            32
#define  APPACTION_NOCANCEL            64
#define  APPACTION_NOEDIT             128
#define  APPACTION_NOSEEK             256
#define  APPACTION_NOFIELDS           512

#define  APPACTION_NONAVIGATION       APPACTION_NOGOTOP + ;
                                      APPACTION_NOPREVIOUS + ;
                                      APPACTION_NONEXT + ;
                                      APPACTION_NOGOBOTTOM + ;
                                      APPACTION_NOSEEK
                                      
#define  APPACTION_NOMODIFY           APPACTION_NOINSERT + ;
                                      APPACTION_NODELETE + ;
                                      APPACTION_NOEDIT

#define  APPACTION_NONE               APPACTION_NONAVIGATION + ;
                                      APPACTION_NOCANCEL + ;
                                      APPACTION_NOMODIFY


******************************************************************************
* Constants used for the STYLE option of the APPEDIT command
******************************************************************************
#define  APPSTYLE_NOBORDER                 1
#define  APPSTYLE_NOTITLEBAR               2
#define  APPSTYLE_NOFRAMECONTROLS          4
#define  APPSTYLE_NOHEADING                8
#define  APPSTYLE_NOSTATUS                16
#define  APPSTYLE_ACTIONICONS             32
#define  APPSTYLE_ACTIONTEXT              64
#define  APPSTYLE_ACTIONTOP              128
#define  APPSTYLE_ACTIONLEFT             256
#define  APPSTYLE_ACTIONBOTTOM           512
#define  APPSTYLE_ACTIONRIGHT           1024
#define  APPSTYLE_RAISED                2048

#define  APPSTYLE_USER                128000
#define  APPSTYLE_HORIZONTAL          APPSTYLE_USER + 128000

#define  APPSTYLE_PLAIN               APPSTYLE_USER + 256000
#define  APPSTYLE_3D                  APPSTYLE_USER + 512000
#define  APPSTYLE_FANCY               APPSTYLE_USER + 1024000
#define  APPSTYLE_SYSTEMDEFAULT       APPSTYLE_USER + 2048000
#define  APPSTYLE_DEFAULT             APPSTYLE_3D


******************************************************************************
* Constants used to access the field attributes array 
******************************************************************************
#define  APPFIELD_NAME                     1
#define  APPFIELD_TYPE                     2
#define  APPFIELD_LEN                      3
#define  APPFIELD_DEC                      4
#define  APPFIELD_ALIAS                    5
#define  APPFIELD_BLOCK                    6
#define  APPFIELD_READONLY                 7
#define  APPFIELD_WIDTH                    8
#define  APPFIELD_HEADING                  9
#define  APPFIELD_FOOTING                 10
#define  APPFIELD_PRESPARAM               11

#define  APPFIELD_COUNT                   11

*******************************************************************************
* Display an APP
*******************************************************************************
#command APPDISPLAY [<mod:MODELESS>] [<sav:SAVE>]    => ;
         appObject:display( <.mod.>, <.sav.> )

#command APPDISPLAY <oApp> [<mod:MODELESS>] [<sav:SAVE>] => ;
         <oApp>:display( <.mod.>, <.sav.> )


*******************************************************************************
* Generic FIELD definition for APPs
*******************************************************************************
#command _APPFIELD [<(a)> ->] <(fld)> INTO <oApp> ;
         [ EXPR    <exp>    ] ;
         [ TYPE    <(typ)>  ] ;
         [ LEN     <len>    ] ;
         [ DEC     <dec>    ] ;
         [ FONT    <(Fft)>  ] ;
         [ COLOR   <Ffg1> [, <Fbg1> ] ] ;
         [ HILITE  <Ffg2> [, <Fbg2> ] ] ;
         [ ALIGN   <Falg>   ] ;
         [ WIDTH   <wid>    ] ;
         [ <ro:RO,READONLY> ] ;
         [ <head:CAPTION,HEADING> <(txt1)>    ;
           [ FONT  <(Cft1)>  ] ;
           [ COLOR <Cfg1> [, <Cbg1> ] ] ;
           [ ALIGN <CAlg1:LEFT,CENTER,RIGHT> ] ;
         ] ;
         [ <foot:COMMENT,FOOTING> <(txt2)>   ;
           [ FONT  <(Cft2)>  ] ;
           [ COLOR <Cfg2> [, <Cbg2> ] ] ;
           [ ALIGN <CAlg2:LEFT,CENTER,RIGHT> ] ;
         ] ;
      => ;
      <oApp>:fieldDef( {<(fld)>,<(typ)>,<len>,<dec>,<(a)>,{||[<a>->]<fld> [:=<exp>]},IIf(<.exp.>,.T.,<.ro.>),<wid>,,,,}, ;
         __PresParam([{XBP_PP_COMPOUNDNAME,<(Fft)>}];
                     [,{XBP_PP_FGCLR,<Ffg1>}];
                     [,{XBP_PP_BGCLR,<Fbg1>}];
                     [,{XBP_PP_HILITE_FGCLR,<Ffg2>}];
                     [,{XBP_PP_HILITE_BGCLR,<Fbg2>}];
                     [,{__ALIGN,<Falg>}]), ;
         __PresParam([{XBP_PP_CAPTION,<(txt1)>}];
                     [,{XBP_PP_COMPOUNDNAME,<(Cft1)>}];
                     [,{XBP_PP_FGCLR,<Cfg1>}];
                     [,{XBP_PP_BGCLR,<Cbg1>}];
                     [,{__ALIGN,<CAlg1>}]), ;
         __PresParam([{XBP_PP_CAPTION,<(txt2)>}];
                     [,{XBP_PP_COMPOUNDNAME,<(Cft2)>}];
                     [,{XBP_PP_FGCLR,<Cfg2>}];
                     [,{XBP_PP_BGCLR,<Cbg2>}];
                     [,{__ALIGN,<CAlg2>}]) )


*******************************************************************************
* Different APPFIELD commands for APPs
*******************************************************************************
#xtranslate   APPFIELD <fld> [<clauses,...>] => ;
             _APPFIELD <fld> INTO appObject [<clauses>]

#xtranslate   APPFIELD <fld> := <exp> [<clauses,...>] => ;
             _APPFIELD <fld> INTO appObject EXPR <exp> [<clauses>]

#xtranslate   APPFIELD <fld> INTO <oApp> [<clauses,...>] => ;
             _APPFIELD <fld> INTO <oApp> [<clauses>]

#xtranslate   APPFIELD <fld> := <exp> INTO <oApp> [<clauses,...>] => ;
             _APPFIELD <fld> INTO <oApp> EXPR <exp> [<clauses>]


*******************************************************************************
* Translate intermediate pseudo functions
*******************************************************************************
// No presentation parameters set
#define  __PresParam()

#xtrans  __PresParam(<x,...>)  => {<x>}

// Alignment 
#xtrans  {__ALIGN,LEFT}    => {XBP_PP_ALIGNMENT,XBPALIGN_LEFT}
#xtrans  {__ALIGN,RIGHT}   => {XBP_PP_ALIGNMENT,XBPALIGN_RIGHT}
#xtrans  {__ALIGN,CENTER}  => {XBP_PP_ALIGNMENT,XBPALIGN_HCENTER}


// POSITION clause unused
#define  __appPos() 

// POSITION { 100, 200 } -> pixel
#xtrans  __appPos( <pos> ) ;
     =>            <pos>

// POSITION 10, 20 -> row, column
#xtrans  __appPos( <pos1>, <pos2> ) ;
     =>          { <pos1>,<pos2>, "RC" }

// POSITION TOP, CENTER
#xtrans  __appPos( <pos1:TOP,LEFT,BOTTOM,RIGHT,CENTER,&> ;
                 [,<pos2:TOP,LEFT,BOTTOM,RIGHT,CENTER,&>]) ;
     =>          { <"pos1">,<"pos2"> }

// SIZE clause unused
#define  __appSiz() 

// SIZE { 400, 250 } -> pixel
#xtrans  __appSiz( <siz> ) ;
     =>            <siz> 

// SIZE 25, 80 -> row, column
#xtrans  __appSiz( <siz1>, <siz2> ) ;
     =>          { <siz1>,<siz2>, "RC" }

// SIZE nHeight, nWidth PERCENT -> percent
#xtrans  __appSiz( <per:PERCENT>, <siz1> [,<siz2>]  ) ;
     =>          { <siz1>,<siz2>, "%" }

#define _APP_CH

#endif  // #ifndef _APP_CH
