//////////////////////////////////////////////////////////////////////
//
//  DAC.CH
//
//  Copyright:
//     Alaska Software, (c) 1999-2023. All rights reserved.         
//  
//  Contents:
//     #define constants for the DAC
//   
//////////////////////////////////////////////////////////////////////


#ifndef  _DAC_CH          
// dac.ch is not yet included

/*
 * DAC is used, so request library
 */
#ifdef __XPP__
#pragma library("adac20b.lib")
#endif


/*
 * DAC META LEVEL
 */
#define DAC_NAME    0x10
#define DAC_OBJECT  0x20

/*
 * DAC_PERMISSION: ACCESS MODE PROPERTIES
 */
#define DAC_READONLY  1
#define DAC_READWRITE 2

/*
 * DAC_ISOLATION: Multi user/client behaviour
 */
#define DAC_EXCLUSIVE      1
#define DAC_REPEATABLEREAD 2
#define DAC_READUNCOMMITED 3
#define DAC_READCOMMITED   4


/*
 * DAC Framework global leveling of defines
 */
#define DAC_SYS                0x00000000
#define DAC_USER               0x0000FFFF


/*
 * DAC Framework CLASS IDs
 */
#define DAC_UNKNOWN            0x0000
#define DAC_SESSION            0x0001
#define DAC_DATASOURCE         0x0002
#define DAC_DATASET            0x0004
#define DAC_SDATASET           0x0008
#define DAC_DDATASET           0x0010
#define DAC_ADATASET           0x0020
#define DAC_ROW                0x0040
#define DAC_FIELD              0x0080
#define DAC_ORDER              0x0100
#define DAC_RELATION           0x0200


/*
 * dacSession defines
 */
#define DAC_SESSION_CONNECTED  (DAC_SYS + 1)
#define DAC_SESSION_DEFAULT    (DAC_SYS + 2)
#define DAC_SESSION_FREE       (DAC_SYS + 3)
#define DAC_SESSION_USED       (DAC_SYS + 4)
#define DAC_SESSION_UNUSED     (DAC_SYS + 5)

/*
 * dacDatasource defines
 */
#define DAC_DATASOURCE_NAME               (DAC_SYS + 1)
#define DAC_DATASOURCE_ISCONNECTED        (DAC_SYS + 2)
#define DAC_DATASOURCE_CONN_HANDLE        (DAC_SYS + 3)
#define DAC_DATASOURCE_CONN_STRING        (DAC_SYS + 4)
#define DAC_DATASOURCE_TRN_ACTIVE         (DAC_SYS + 5)
#define DAC_DATASOURCE_HAS_DICTIONARY     (DAC_SYS + 6)
#define DAC_DATASOURCE_COLLATION          (DAC_SYS + 7)
#define DAC_DATASOURCE_CODEPAGE           (DAC_SYS + 8)
#define DAC_DATASOURCE_ACCESS_MODE        (DAC_SYS + 9)
#define DAC_DATASOURCE_USED               (DAC_SYS + 10)
#define DAC_DATASOURCE_STATEMENT_PROVIDER (DAC_SYS + 11)




/*
 * dacField defines
 */
#define DAC_FIELD_NAME           (DAC_SYS + 1)
#define DAC_FIELD_SYMBOL         (DAC_SYS + 2)
#define DAC_FIELD_TYPE           (DAC_SYS + 3)
#define DAC_FIELD_VALTYPE        (DAC_SYS + 4)
#define DAC_FIELD_NATIVETYPE     (DAC_SYS + 5)
#define DAC_FIELD_LENGTH         (DAC_SYS + 6) 
#define DAC_FIELD_DECIMALS       (DAC_SYS + 7)
#define DAC_FIELD_NULLABLE       (DAC_SYS + 8)
#define DAC_FIELD_READONLY       (DAC_SYS + 9)
#define DAC_FIELD_SYSTEM         (DAC_SYS + 10)
#define DAC_FIELD_CORE_SIZE      10

#define DAC_FIELD_INDEXED        (DAC_SYS + 11)
#define DAC_FIELD_PRIMARYKEY     (DAC_SYS + 12)

#define DAC_FIELD_DEFAULT        (DAC_SYS + 13)
#define DAC_FIELD_DESCRIPTION    (DAC_SYS + 14)

#define DAC_FIELD_RULE           (DAC_SYS + 15)
#define DAC_FIELD_RULEMESSAGE    (DAC_SYS + 16)

#define DAC_FIELD_IDENT          (DAC_SYS + 17)
#define DAC_FIELD_IDENTSEED      (DAC_SYS + 18)
#define DAC_FIELD_IDENTINCR      (DAC_SYS + 19)

#define DAC_FIELD_EXTENDED_SIZE  19

#define DAC_FIELD_PICTURE        (DAC_SYS + 20)
#define DAC_FIELD_CAPTION        (DAC_SYS + 21)
#define DAC_FIELD_VIEWER         (DAC_SYS + 22)
#define DAC_FIELD_EDITOR         (DAC_SYS + 23)

#define DAC_FIELD_SHEMA_SIZE     23

/*
 * dacRelation and referential integrity
 */
#define DAC_RELATION_NAME         (DAC_SYS + 1)
#define DAC_RELATION_SELECTIVE    (DAC_SYS + 2)
#define DAC_RELATION_CHILDNAME    (DAC_SYS + 3)
#define DAC_RELATION_CHILDORDNAME (DAC_SYS + 4)
#define DAC_RELATION_PARENTNAME   (DAC_SYS + 5)
#define DAC_RELATION_EXPR         (DAC_SYS + 6)
#define DAC_RELATION_CORE_SIZE      6

#define DAC_RELATION_TYPE         (DAC_SYS + 7)
#define DAC_RELATION_RI_INSERT    (DAC_SYS + 8)
#define DAC_RELATION_RI_DELETE    (DAC_SYS + 9)
#define DAC_RELATION_RI_UPDATE    (DAC_SYS + 10)
#define DAC_RELATION_DESCRIPTION  (DAC_SYS + 11)
#define DAC_RELATION_SHEMA_SIZE     11

#define DAC_RELATION_ONE_TO_MANY  1
#define DAC_RELATION_ONE_TO_ONE   2
#define DAC_RELATION_MANY_TO_MANY 4

#define DAC_RI_IGNORE   1
#define DAC_RI_CASCADE  2
#define DAC_RI_RESTRICT 4

#define DAC_XML_IDENT             2
#define DAC_XML_FLAT              1
#define DAC_XML_MASTER_DETAIL     2

/*
 * DAC order types
 */
#define DAC_REGULAR               0
#define DAC_UNIQUE                1 
#define DAC_CANDIDATE             2 
#define DAC_PRIMARY               4
#define DAC_SUBINDEX              8 
#define DAC_CUSTOM               16
#define DAC_DESCEND              32

/*
 * DAC error codes
 */
#define DAC_ERR_SUBCODE         8500
#define DAC_ERR_MISSING_PARAM   8501
#define DAC_NEED_DBE            8502
#define DAC_DBE_NOT_AVA         8503
#define DAC_SYSOBJ_CREATE       8504
#define DAC_CONNECT_FAILED      8505
#define DAC_INTEGRITY_ERROR     8506
#define DAC_NEED_CONNECTION     8507
#define DAC_NESTED_TXN          8508
#define DAC_ERR_LASTCODE        8509

// dac.ch is included
#define  _DAC_CH         

#endif                    // #ifndef _DAC_CH
