//////////////////////////////////////////////////////////////////////
//
//  DLL.CH
//
//  Copyright:
//       Alaska Software, (c) 1998-2023. All rights reserved.         
//  
//  Contents:
//       Constants used for DLL calling conventions
//       Command to load non Xbase++ DLLs during runtime and call
//       DLL functions dynamically
//   
//////////////////////////////////////////////////////////////////////


// Dll.ch is not included
#ifndef  _DLL_CH

// Support for the EXTERN commands
#ifdef  __XPP__
#include "extern.ch"
#endif

// Support for STRUCTURE commands
#include "struct.ch"

// Calling convention constants
#define  DLL_CONVENTION_MASK     0x000000FF
#define  DLL_SYSTEM              0x00000004
#define  DLL_CDECL               0x00000008
#define  DLL_STDCALL             0x00000020
#define  DLL_XPPCALL             0x00000080

#define DLL_OSAPI              DLL_STDCALL

// calling mode constants
#define  DLL_CALLMODE_NORMAL     0x00000000
#define  DLL_CALLMODE_COPY       0x00002000
#define  DLL_CALLMODE_RESTOREFPU 0x00004000

// parameter type constants for DllPrepareCall()
#define DLL_TYPE_MASK            0x00FF0000
#define DLL_TYPE_INT16           0x00010000
#define DLL_TYPE_UINT16          0x00020000
#define DLL_TYPE_INT32           0x00030000
#define DLL_TYPE_UINT32          0x00040000
#define DLL_TYPE_INT64           0x00050000
#define DLL_TYPE_UINT64          0x00060000
#define DLL_TYPE_FLOAT32         0x00070000
#define DLL_TYPE_FLOAT64         0x00080000
#define DLL_TYPE_STRING          0x00090000
#define DLL_TYPE_IDISPATCH       0x000A0000
#define DLL_TYPE_WSTRING         0x000B0000
#define DLL_TYPE_CALLBACK        0x000C0000
#define DLL_TYPE_ACALLBACK       0x000D0000
#define DLL_TYPE_XPPVALUE        0x000E0000
#define DLL_TYPE_STRUCTURE       0x000F0000
#define DLL_TYPE_BOOL32          0x00100000
#define DLL_TYPE_BOOL8           0x00200000

// Automatic Library search
#define WIN32API "WIN32API"

// DllInfo() #defines
#define DLL_INFO_HANDLE         1
#define DLL_INFO_NAME           2
#define DLL_INFO_PATHNAME       3
#define DLL_INFO_LOADED         4
#define DLL_INFO_TYPE           5
#define DLL_INFO_LIST           6
#define DLL_INFO_PREFIX         7
#define DLL_INFO_UNLOADABLE     8
#define DLL_INFO_USAGELIST      9
#define DLL_INFO_FUNCLIST      10
#define DLL_INFO_CLASSFUNCLIST 11
#define DLL_INFO_IMPORTS       12
#define DLL_TYPE_UNKNOWN        0
#define DLL_TYPE_GENERAL        1
#define DLL_TYPE_XPP_STATIC     2
#define DLL_TYPE_XPP_DYNAMIC    3
#define DLL_TYPE_XPP_DYNAMIC_NOUNLOAD 4

#ifdef  __XPP__

// DLLFUNCTION command
#command  DLLFUNCTION <Func>([<x,...>]) ;
                USING <sys:CDECL,OSAPI,STDCALL,SYSTEM> ;
                 FROM <(Dll)> ;
       => ;
             FUNCTION <Func>([<x>]);;
                LOCAL nDll:=DllLoad(<(Dll)>);;
                LOCAL xRet:=DllCall(nDll,__Sys(<sys>),<(Func)>[,<x>]);;
                      DllUnLoad(nDll);;
               RETURN xRet

#command  STATIC DLLFUNCTION <Func>([<x,...>]) ;
                USING <sys:CDECL,OSAPI,STDCALL,SYSTEM> ;
                 FROM <(Dll)> ;
       => ;
             STATIC FUNCTION <Func>([<x>]);;
                LOCAL nDll:=DllLoad(<(Dll)>);;
                LOCAL xRet:=DllCall(nDll,__Sys(<sys>),<(Func)>[,<x>]);;
                      DllUnLoad(nDll);;
               RETURN xRet

#xtrans __Sys( CDECL )   => DLL_CDECL
#xtrans __Sys( OSAPI )   => DLL_OSAPI
#xtrans __Sys( STDCALL ) => DLL_STDCALL
#xtrans __Sys( SYSTEM )  => DLL_SYSTEM

#xcommand FUNCTION <Func>([<x1,...>] @ [<x2,...>]) ;
       => FUNCTION <Func>([<x1>][<x2>])

#xcommand STATIC FUNCTION <Func>([<x1,...>] @ [<x2,...>]) ;
       => STATIC FUNCTION <Func>([<x1>][<x2>])

#endif // __XPP__

// constants for LoadResource() - resource type
#define RES_STRING               6
#define RES_VERSION             16
#define RES_RAWSTRING         1006
#define RES_VERSIONFIXED      1016

// constants for LoadResource() - version return
#define RES_VERSION_KEY          1
#define RES_VERSION_VALUE        2

#define RES_PRODVER_LS           1
#define RES_PRODVER_MS           2
#define RES_FILEVER_LS           3
#define RES_FILEVER_MS           4
#define RES_FILETIME_LS          5
#define RES_FILETIME_MS          6

// some predefined module handles
#define XPP_MOD_EXE      0
#define XPP_MOD_NLS      0xFFFFFFFF
#define XPP_MOD_RT1      0xFFFFFFFE
#define XPP_MOD_UI1      0xFFFFFFFD
#define XPP_MOD_UI2      0xFFFFFFFC

#define _DLL_CH
#endif

