//////////////////////////////////////////////////////////////////////
//
//  ERROR.CH
//
//  Copyright:
//      Alaska Software, (c) 1998-2023. All rights reserved.         
//  
//  Contents:
//      #define constants for Error objects
//           -> oError:severity
//           -> oError:genCode
//   
//////////////////////////////////////////////////////////////////////


// Error.ch is not included
#ifndef  _ERROR_CH                     
#define  _ERROR_CH

//*****************************************************************************
// #defines for oError:severity
//*****************************************************************************

// No error
#define  XPP_ES_WHOCARES            0  
// Warning
#define  XPP_ES_WARNING             1  
// Error
#define  XPP_ES_ERROR               2  
// Program must be terminated
#define  XPP_ES_FATAL               3  

//*****************************************************************************
// #defines for oError:genCode
//*****************************************************************************

// no Error
#define  XPP_ERR_NONE               0  
// Parameter has a wrong value
#define  XPP_ERR_ARG_VALUE          1  
// Parameter has a wrong data type
#define  XPP_ERR_ARG_TYPE           2  
// Missing parameters in call of function or method
#define  XPP_ERR_ARG_COUNT          3  
// Error in array index
#define  XPP_ERR_ARRAY_BOUNDS       4  
// Numeric overflow
#define  XPP_ERR_NUMOVERFLOW       10  
// Division by zero
#define  XPP_ERR_ZERODIV           11  
// Invalid numeric value (e.g. 3 % 0 or float number is too large for array index)
#define  XPP_ERR_NUMERR            12  
// Not enough memory or swapping space available
#define  XPP_ERR_MEMORY_FULL       15  
// Stack overflow
#define  XPP_ERR_STACK_OVERFLOW    16  

// Syntax error in macro
#define  XPP_ERR_SYNTAX            20  
// Function is not declared
#define  XPP_ERR_NOFUNC            21  
// Unknown variable. A variable name identifies neither 
// a PRIVATE nor a PUBLIC variable
#define  XPP_ERR_NOVAR             22  
// Object has no method with this name
#define  XPP_ERR_NOMETHOD          23  
// Error in the METHOD..IS definition for a method: 
// the message identifier is already used for another 
// method and is not allowed for this method
#define  XPP_ERR_METHOD_DEF        24  
// Access to method is not allowed in this context
#define  XPP_ERR_METHOD_ACCESS     25  
// Object has no member variable with this name
#define  XPP_ERR_NOMEMBERVAR       26  
// Error in the VAR..IS definition for a member variable: 
// the message identifier is already used for another member variable
// or class name and is not allowed for this member variable
#define  XPP_ERR_VAR_DEF           27  
// Access to member variable is not allowed in this context.
#define  XPP_ERR_MEMBERVAR_ACCESS  28  
// Wrong data type for member variable
#define  XPP_ERR_MEMBERVAR_TYPE    29  
// access to instance method not allowed in class object
#define  XPP_ERR_INSTANCE_METHOD   30  
// access to instance member variable not allowed in class object
#define  XPP_ERR_INSTANCE_VAR      31  
// error within the class declaration
#define  XPP_ERR_CLASS_SYNTAX      32  
// no instances allowed for this class: 
// class contains DEFERRED methods or is destroyed
#define  XPP_ERR_CLASS_INSTANCE    33  
// class is already defined
#define  XPP_ERR_CLASS_CONFLICT    34  
// call of not implemented DEFERRED method 
#define  XPP_ERR_METHOD_DEFERRED   35  
// method is FINAL and cannot be overloaded
#define  XPP_ERR_METHOD_FINAL      36  
// class is undefined
#define  XPP_ERR_CLASS_UNKNOWN     37
// Receiver of message is not an object.
#define  XPP_ERR_NOOBJECT          38
// Class is final, subclassing not allowed
#define  XPP_ERR_CLASS_FINAL       39 


// operating system error: occurs if the error cannot be identified
// more precisely.
#define  XPP_ERR_DOS               40  
// Internal data structures corrupted
// (an unexpected OS error occured or corrupted XPF file)
#define  XPP_ERR_CORRUPTION        41  
// XPF file has invalid version number
#define  XPP_ERR_LOAD_VERSION      42  
// attempt to save non persistent data
#define  XPP_ERR_SAVE_UNSUPPORTED  43  

// DMLB sub-system is not initialized
#define  XPP_ERR_DMLB_INIT         50  
// Generic error in DMLB framework
#define  XPP_ERR_DMLB_FRAMEWORK    51  
// Invalid DLL name for DBE
#define  XPP_ERR_DBE_DLLNAME       52  
// DBE build name already in use
#define  XPP_ERR_DBE_BUILDNAMEUSED 53  
// DBE build error
#define  XPP_ERR_DBE_BUILD         54  
// DBE component is defective
#define  XPP_ERR_DBE_COMPONENT     55  
// DBE initialization failed
#define  XPP_ERR_DBE_INIT          56  
// DBE deinitialization failed
#define  XPP_ERR_DBE_UNINIT        57  
// Operation is not supported by DBE
#define  XPP_ERR_DBE_UNSUPPORTED   58  
// DBE private/specific error
#define  XPP_ERR_DBE_INTERN        59  
// No default DBE available/defined
#define  XPP_ERR_DBE_NODEFAULT     60  
// Invalid DBE name (DBE is not loaded or compound DBE is not built)
#define  XPP_ERR_NODBE             61  
// Invalid data type for database field
#define  XPP_ERR_DATATYPE          62  
// Length of database field was exceeded
#define  XPP_ERR_DATAWIDTH         63  
// Invalid length of index key
#define  XPP_ERR_KEYWIDTH          64  
// Unknown symbol for database field
#define  XPP_ERR_NOFIELD           65  

// Unknown symbol for alias
#define  XPP_ERR_NOALIAS           66  
// Symbol is already in use (e.g. FIELD,TAG)
#define  XPP_ERR_DUPNAME           67  

// No table available/no database open
#define  XPP_ERR_NOTABLE           68  
// No order available/no index open
#define  XPP_ERR_NOORDER           69  

// File can not be created
#define  XPP_ERR_CREATE            70  
// File can not be opened
#define  XPP_ERR_OPEN              71  
// Error while closing a file
#define  XPP_ERR_CLOSE             72  
// Error while reading a file
#define  XPP_ERR_READ              73  
// Error while writing to a file
#define  XPP_ERR_WRITE             74  

// Operation requires a file to be exclusively opened
#define  XPP_ERR_EXCL_REQUIRED     75  
// File lock is required for this operation
#define  XPP_ERR_LOCK_REQUIRED     76  
// File is open in read only mode
#define  XPP_ERR_READONLY          77  

// Auto lock error during APPEND BLANK
#define  XPP_ERR_APPENDLOCK        78  
// Record lock failed
#define  XPP_ERR_LOCK              79  

// Lost Update error was detected by DMLB
#define  XPP_ERR_LOSTUPDATES       80  

// no more room in WorkSpace for WorkArea
#define  XPP_ERR_WKS_OVERFLOW      90  
// operation reject/not allowed
#define  XPP_ERR_REQ_REJECT        91  
// database engine and active session do not match
#define  XPP_ERR_SESSION_CONFLICT  92
// session is required for this operation
#define  XPP_ERR_SESSION_REQUIRED  93 
// compound session not allowed for this operation
#define  XPP_ERR_COMPOUND_SESSION  94
// custom index option not possible
#define  XPP_ERR_CUSTOM_FAILED     95
// duplicate key, key not unique
#define  XPP_ERR_DUP_KEY           96
// field is readonly, write denied
#define  XPP_ERR_FIELD_READONLY    97
// Runtime DLLs DO not match
#define XPP_ERR_DLLS_DONT_MATCH    98

// Operation is not allowed in this thread
#define  XPP_ERR_THREAD_ID        100  
// Error during printing or spooling
#define  XPP_ERR_PRINT            101  
// Method is not implemented/is unavailable
#define  XPP_ERR_METHOD_NOT_IMPLEMENTED 102 
// (Compatibility)
#define  XPP_ERR_METHOD_NOT_OVERLOADED  XPP_ERR_METHOD_NOT_IMPLEMENTED
// The object being accessed is not registered
// (Probably because the :init() method has not been called)
#define  XPP_ERR_OBJECT_ACCESS    103  
// The object (XBP) is in the wrong state to perform the operation
#define  XPP_ERR_OBJECT_STATE     104  
// Error while creating an object (XBP)
#define  XPP_ERR_OBJECT_CREATION  105  
// An invalid matrix was passed to a Gra..() operation.
#define  XPP_ERR_ILLEGAL_MATRIX   130  
// Wrong linking mode for operation
#define  XPP_ERR_WRONG_APPTYPE    133  
// A printer resource either isn't installed or is currently unavailable
#define  XPP_ERR_PRINTER_NA       134  
// A resource such as a bitmap is currently unavailable
#define  XPP_ERR_RESOURCE_NA      135  

// The functionality is not supported (under the current OS or for other reasons)
#define  XPP_ERR_NOT_SUPPORTED    140  

// Error with dynamic loaded function
#define  XPP_ERR_DYNAMIC_CALL     141  

// DLL module couldn't be loaded 
#define  XPP_ERR_MODULE_LOAD      142

// DLL module was created with an incompatible version
#define  XPP_ERR_MODULE_VERSION    143

// unsupported calling convention
#define  XPP_ERR_CALLING_CONVENTION  144

// DllLoad() needs module compiled /dll:dynamic
#define  XPP_ERR_MODULE_STATIC       145

// OCX Error while processing Property/Method
#define  XPP_ERR_OCX_ERROR           146

// Invalid message for method or member definition
#define  XPP_ERR_MESSAGE_INVALID     147

// Operating system thread cannot be started
#define  XPP_ERR_THREAD_CREATE       148

// Only for C-API:
// Function was terminated by BREAK()
#define  XPP_ERR_BREAK            333  
// Container has a wrong type
#define  XPP_ERR_CONTYPE          334  
// Write lock is not allowed for this string since a read lock has already been set
#define  XPP_ERR_READLOCKED       335  
// Read lock is not allowed for this string since a write lock has already been set
#define  XPP_ERR_WRITELOCKED      336  
// The limit for string locks has been reached for this container
#define  XPP_ERR_LOCKLIMIT        337  
// String container is not locked
#define  XPP_ERR_NOTLOCKED        338  
// Handle is invalid or not in the correct state (locked/unlocked)
#define  XPP_ERR_INVALID_HANDLE   339  

// #defines for Error():SetErrorMode()
#define  ERR_MODE_GC         0
#define  ERR_MODE_GUI        1
#define  ERR_ACTION_FATAL    0
#define  ERR_ACTION_IGNORE   1
#define  ERR_ACTION_POPUP    2

#ifdef __XBASE2__
#ifndef _XB2_CH
#include "xb2.ch"
#endif

//*****************************************************************************
// Compatibility:
//*****************************************************************************
#define ES_WHOCARES        XPP_ES_WHOCARES
#define ES_WARNING         XPP_ES_WARNING
#define ES_ERROR           XPP_ES_ERROR
#define ES_CATASTROPHIC    XPP_ES_FATAL
// XPP_ERR_ARG_VALUE or XPP_ERR_ARG_TYPE
#define EG_ARG             -1 
#define EG_BOUND           XPP_ERR_ARRAY_BOUNDS
// impossible
#define EG_STROVERFLOW     -1 
#define EG_NUMOVERFLOW     XPP_ERR_NUMOVERFLOW
#define EG_ZERODIV         XPP_ERR_ZERODIV
#define EG_NUMERR          XPP_ERR_NUMERR
#define EG_SYNTAX          XPP_ERR_SYNTAX
// impossible
#define EG_COMPLEXITY      -1 
#define EG_MEM             XPP_ERR_MEMORY_FULL
#define EG_NOFUNC          XPP_ERR_NOFUNC
#define EG_NOMETHOD        XPP_ERR_NOMETHOD
#define EG_NOVAR           XPP_ERR_NOVAR
#define EG_NOALIAS         XPP_ERR_NOALIAS
#define EG_NOVARMETHOD     XPP_ERR_NOMEMBERVAR
#define EG_BADALIAS        XPP_ERR_NOALIAS
// Internally handled!
#define EG_DUPALIAS        -1 

#define EG_CREATE          XPP_ERR_CREATE
#define EG_OPEN            XPP_ERR_OPEN
#define EG_CLOSE           XPP_ERR_CLOSE
#define EG_READ            XPP_ERR_READ
#define EG_WRITE           XPP_ERR_WRITE
#define EG_PRINT           XPP_ERR_PRINT
#define EG_UNSUPPORTED     XPP_ERR_NOT_SUPPORTED
#define EG_LIMIT           XPP_ERR_LIMIT
#define EG_CORRUPTION      XPP_ERR_CORRUPTION
#define EG_DATATYPE        XPP_ERR_DATATYPE
#define EG_DATAWIDTH       XPP_ERR_DATAWIDTH
#define EG_NOTABLE         XPP_ERR_NOTABLE
#define EG_NOORDER         XPP_ERR_NOORDER
#define EG_SHARED          XPP_ERR_EXCL_REQUIRED
#define EG_UNLOCKED        XPP_ERR_LOCK_REQUIRED
#define EG_READONLY        XPP_ERR_READONLY
#define EG_APPENDLOCK      XPP_ERR_APPENDLOCK
#define EG_LOCK            XPP_ERR_LOCK
#endif

#endif // _ERROR_CH                  
