//////////////////////////////////////////////////////////////////////
//
//  FILEIO.CH
//
//  Copyright:
//       Alaska Software, (c) 1998-2023. All rights reserved.         
//  
//  Contents:
//       #define constants for the low level file functions
//       -> FCreate(), FOpen() and FSeek()
//   
//////////////////////////////////////////////////////////////////////


// Fileio.ch is not included
#ifndef  _FILEIO_CH

/***************************************************
* Universal return value for failed operations
****************************************************/

#define F_ERROR      (-1)

/***************************************************
* File handle attributes for FCreate() and FOpen()
****************************************************/
// Handle can be inherited
#define  FA_INHERITABLE 0x00000008

/***************************************************
* File attributes for FCreate()
****************************************************/

// Create file w/o attribute (default)
#define  FC_NORMAL      0
// Create file with read only attribute
#define  FC_READONLY    1
// Create file with hidden attribute
#define  FC_HIDDEN      2
// Create system file
#define  FC_SYSTEM      4
// Create file that is deleted when closed
#define  FC_AUTODELETE  0x04000000

/***************************************************
* Modes for opening a file with FOpen()
****************************************************/

// Read only (default)
#define  FO_READ        0
// Write only
#define  FO_WRITE       1
// Read and write
#define  FO_READWRITE   2

/***************************************************
* Modes for opening a file with FOpen() for SHARED access
*   Example:  FOpen( "Filename", FO_READWRITE + FO_DENYWRITE )
*   Other processes (or workstations) have no write access
****************************************************/

// Compatibility mode (default)
#define  FO_COMPAT      0
// File will be exclusively opened
#define  FO_EXCLUSIVE  16
// Other processes have no write access
#define  FO_DENYWRITE  32
// Other processes have no read access
#define  FO_DENYREAD   48
// same as FO_SHARED
#define  FO_DENYNONE   64
// Other processes have read/write access
#define  FO_SHARED     64

/***************************************************
* Starting point for the positioning of the file pointer using FSeek()
****************************************************/

// Starting point is begin of file
#define  FS_SET         0
// Starting point is the current position of the file pointer
#define  FS_RELATIVE    1
// Starting point is end of file
#define  FS_END         2

// standard file handles
#ifdef __WIN32__
#define  FH_STDIN   -10
#define  FH_STDOUT  -11
#define  FH_STDERR  -12
#else
#define  FH_STDIN   0
#define  FH_STDOUT  1
#define  FH_STDERR  2
#endif

// return values of FTimeCmp
#define FT_YOUNGER  1           // file time(file1) > file time(file2)
#define FT_EQUAL    0           // file time(file1) == file time(file2)
#define FT_OLDER    -1          // file time(file1) < file time(file2)
#define FT_F1ERROR  -100        // file 1 error
#define FT_F2ERROR  -200        // file 2 error

// possible modes of FTimeCmp
#define FT_CREATED      0
#define FT_LASTWRITE    1
#define FT_LASTACCESS   2

// Fileio.ch is included
#define  _FILEIO_CH

#endif                     // #ifndef _FILEIO_CH
