//////////////////////////////////////////////////////////////////////
//
//  GET.CH
//
//  Copyright:
//      Alaska Software, (c) 1998-2023. All rights reserved.         
//  
//  Contents:
//      #define constants for oGet:exitState and
//      #command direktives for the Get system
//   
//////////////////////////////////////////////////////////////////////


// Get.ch is not included
#ifndef  _GET_CH       

*******************************************************************************
* Defines for oGet:exitState (replaces Getexit.ch)
*******************************************************************************

// Continue READ 
#define  GE_NOEXIT  0  
// Go to Previous Get
#define  GE_UP      1  
// Go to next Get
#define  GE_DOWN    2  
// Go to first Get
#define  GE_TOP     3  
// Go to last Get
#define  GE_BOTTOM  4  
// Enter key was pressed, go to next Get
#define  GE_ENTER   5  
// Terminate READ and save data
#define  GE_WRITE   6  
// Terminate READ and do not save data
#define  GE_ESCAPE  7  
// WHEN condition failed (oGet:preBlock returned .F.)
#define  GE_WHEN    8  
// Get was terminated by mouse click
#define  GE_MOUSE   9  
// Set the focus to the last object which had the focus
#define  GE_LASTGET 10 

*******************************************************************************
* Command: @...GET
*******************************************************************************

// Intermediate pseudo functions
#xtrans __gName(<var>)                    =>  <"var">
#xtrans __gName(<var>\[<i,...>])          =>  <"var">
#xtrans __gName(<var>\[<i>]\[<j>])        =>  <"var">
                                               
#xtrans __gBlock(<var>)                   => anchorCB(@<var>)
#xtrans __gBlock(\&<var>)                 => ;          
        IF(isFieldVar(<var>),                ;
          anchorCB(@FIELD->&<var>),          ;
          anchorCB(@&<var>))

#command  @ <nRow>, <nCol> GET <Var> ;
                      [PICTURE <cPict>] ;
                        [VALID <lValid>] ;
                         [WHEN <lWhen>] ;
                         [SEND <message>] ;
      =>  aadd( getList, ;
            ( Get():new( <nRow>, <nCol>, __gBlock(<Var>), __gName(<Var>), ;
                        <cPict>, NIL, <{lValid}>, <{lWhen}>) ):display() ) ;
       [; Atail( getList ):<message>]

*******************************************************************************
* Command: @...SAY...GET
*******************************************************************************

#command  @ <nRow>, <nCol> SAY <Say> [<sayOptions,...>] ;
                           GET <Var> [<getOptions,...>] ;
      =>  @ <nRow>, <nCol> SAY <Say> [<sayOptions>] ;;
          @ row(), col()+1 GET <Var> [<getOptions>]

*******************************************************************************
* Command: @...GET...RANGE (is translated to @...GET...VALID)
*******************************************************************************

#command  @ <nRow>, <nCol> GET <Var> [<Options,...>] ;
                         RANGE <low>, <high> [<moreOptions,...>] ;
      =>  @ <nRow>, <nCol> GET <Var> [<Options>] ;
                         VALID {|_x| RangeCheck(_x, <low>, <high>)} ;
                         [<moreOptions>]

*******************************************************************************
* Command: @...GET...COLOR
*******************************************************************************

#command  @ <nRow>, <nCol> GET <Var>    [<Options,...>] ;
                         COLOR <cColor> [<moreOptions,...>] ;
      =>  @ <nRow>, <nCol> GET <Var>    [<Options>] ;
                          SEND colorDisp(<cColor>) [<moreOptions>]

*******************************************************************************
* Commands: READ, READ SAVE, CLEAR GETS
*******************************************************************************

#command READ SAVE          => ReadModal(getList)
#command READ               => ReadModal(getList) ; getList := {}
#command CLEAR GETS         => ReadKill(.T.) ; getList := {}


*******************************************************************************
* Translation of GETNEW()
*******************************************************************************
#xtranslate getnew => get():new


// Get.ch is included
#define  _GET_CH            

#endif                      // #ifndef _GET_CH

// * EOF *
