//////////////////////////////////////////////////////////////////////
//
//  GRAERROR.CH
//
//  Copyright:
//      Alaska Software, (c) 1998-2023. All rights reserved.         
//  
//  Contents:
//      #defines for error codes of the GRA engine (-> GraError())
//   
//////////////////////////////////////////////////////////////////////


// GraError.ch is not included
#ifndef  _GRAERROR_CH              

//****************************************************************************
// Fehlerdefinitionen fuer XbpPS:LastError()
//****************************************************************************

#define GRA_ERR_NO_ERROR        0
// generic error, no further error information was available
#define GRA_ERR_GENERIC         1  
// the PS is in the wrong state for this operation, e.g. opening a path was tried
// while another path was already open
#define GRA_ERR_PS_CONTEXT      2  
// the specified coordinates could not be accepted by the PS and Device
#define GRA_ERR_COORDINATE      3  
// the device is in the wrong state for this operation, 
// e.g. it is currently connected to a PS and therefore cannot be destroyed
#define GRA_ERR_DC_STATE        4  
// the device driver was not found or a device specific error occured
#define GRA_ERR_DEVICE_DRIVER   5  
// the system is out of resources for this operation, e.g. the segment
// exceeds max segment size, or the font file is to large to be loaded
#define GRA_ERR_SYS_RESOURCES   6  
// the resource is currently not available,
// e.g. because the Bitmap is locked by another thread
#define GRA_ERR_RESOURCE_ACCESS 7  
// the metafile has different page units,
// or the bitmap different depth than the destination PS
#define GRA_ERR_MISMATCH        8  
// one or more of the specified attributes
// are illegal or unsupported for this PS and Device
#define GRA_ERR_INVALID_ATTRIB  9  
// one or more parameters of the operation have
// illegal values, e.g. the angle was illegal for graArc or the
// PageViewport was illegal for XbpPS:SetViewPort
#define GRA_ERR_PARAMETER_VALUE 10 
// the operation is not allowed on a Micro PS
#define GRA_ERR_MICROPS_OPERATION 11 
// an error occured while spooling a print job
// e.g. because startDoc was not issued, or
// the job was aborted, or illegal driver data
// has been specified when opening the printer
#define GRA_ERR_PRINTING        12 
// the data which should be processed is corrupt, e.g. a corrupt 
// Metafile data was encountered while playing it
#define GRA_ERR_DATA_ERROR      13 
// generic segment error occured, e.g. because the specified segment 
// does not exist, or an attempt to open an already existing segment
// id within a meta file was made when the drawing mode was draw + retain
#define GRA_ERR_SEGMENTS        14 

#define _GRAERROR_CH
#endif

