//////////////////////////////////////////////////////////////////////
//
//  INKEY.CH
//
//  Copyright:
//       Alaska Software, (c) 1998-2023. All rights reserved.         
//  
//  Contents:
//       #define constants for the return value of INKEY()
//   
//  Remarks:
//       The function INKEY() exists for compatibility reasons.
//       Instead of INKEY() the function APPEVENT() should be used!
//   
//////////////////////////////////////////////////////////////////////


// Inkey.ch is not included
#ifndef  _INKEY_CH         

*******************************************************************************
* Cursor movement
*******************************************************************************

// Up arrow            | Strg+E
#define  K_UP           5  
// Down arrow          | Strg+X
#define  K_DOWN        24  
// Left arrow          | Strg+S
#define  K_LEFT        19  
// Right arrow         | Strg+D
#define  K_RIGHT        4  
// Page up             | Strg+R
#define  K_PGUP        18  
// Page down           | Strg+C
#define  K_PGDN         3  
// Home                | Strg+A
#define  K_HOME         1  
// End                 | Strg+F
#define  K_END          6  
                           ** Ctrl + cursor movement keys **

// Ctrl+up arrow
#define  K_CTRL_UP    397  
// Ctrl+down arrow
#define  K_CTRL_DOWN  401  
// Ctrl+left arrow     | Ctrl+Z
#define  K_CTRL_LEFT   26  
// Ctrl+right arrow    | Ctrl+B
#define  K_CTRL_RIGHT   2  
// Ctrl+page up        | Ctrl+-
#define  K_CTRL_PGUP   31  
// Ctrl+page down      | Ctrl+^
#define  K_CTRL_PGDN   30  
// Ctrl+home           | Ctrl+]
#define  K_CTRL_HOME   29  
// Ctrl+end            | Ctrl+W
#define  K_CTRL_END    23  
                           ** Alt + cursor movement keys **

// Alt+up arrow
#define  K_ALT_UP     408  
// Alt+down arrow
#define  K_ALT_DOWN   416  
// Alt+left arrow 
#define  K_ALT_LEFT   411  
// Alt+right arrow
#define  K_ALT_RIGHT  413  
// Alt+page up    
#define  K_ALT_PGUP   409  
// Alt+page down  
#define  K_ALT_PGDN   417  
// Alt+home       
#define  K_ALT_HOME   407  
// Alt+end        
#define  K_ALT_END    415  

*******************************************************************************
* Keys for editing
*******************************************************************************

// Delete    | Ctrl+G
#define  K_DEL          7  
// Back space| Ctrl+H
#define  K_BS           8  
// Tab       | Ctrl+I
#define  K_TAB          9  
// Insert    | Ctrl+V
#define  K_INS         22  
// Shift-Tab
#define  K_SH_TAB     271  
                           ** Ctrl + keys for editing

// Ctrl+back space
#define  K_CTRL_BS    127  
// Ctrl+insert
#define  K_CTRL_INS   402  
// Ctrl+delete
#define  K_CTRL_DEL   403  
// Ctrl+tab
#define  K_CTRL_TAB   404  
                           ** Alt + keys for editing

// Alt+back space
#define  K_ALT_BS     270  
// Alt+insert
#define  K_ALT_INS    418  
// Alt+delete
#define  K_ALT_DEL    419  
#define  K_ALT_TAB    #error ALT_TAB not available in OS/2

*******************************************************************************
* Miscellaneous keys
*******************************************************************************

// Enter  , Ctrl+M
#define  K_ENTER           13  
// Return , Ctrl+M
#define  K_RETURN          13  
// Esc    , Ctrl+[
#define  K_ESC             27  
// Space bar
#define  K_SPACE           32  
                           ** Ctrl + miscellaneous keys **

// Ctrl+Enter
#define  K_CTRL_ENTER      10  
// Ctrl+Return
#define  K_CTRL_RETURN     10  
// Ctrl+Return
#define  K_CTRL_RET        10  
// Ctrl+Print
#define  K_CTRL_PRTSCR    379  
// Ctrl+?
#define  K_CTRL_QUESTION  309  
                           ** Alt + miscellaneous keys **

// Alt+Enter
#define  K_ALT_ENTER      284  
// Alt+Return
#define  K_ALT_RETURN     284  
// Alt+Equals
#define  K_ALT_EQUALS     387  
#define  K_ALT_ESC        #error ALT_ESC not available in OS/2

*******************************************************************************
* Keys codes for letters
*******************************************************************************
                       ** Ctrl+Letter keys **

// Ctrl+A | Home
#define  K_CTRL_A   1  
// Ctrl+B | Ctrl+Right arrow
#define  K_CTRL_B   2  
// Ctrl+C | Page down | Ctrl+ScrollLock
#define  K_CTRL_C   3  
// Ctrl+D | right arrow
#define  K_CTRL_D   4  
// Ctrl+E | up arrow
#define  K_CTRL_E   5  
// Ctrl+F | End
#define  K_CTRL_F   6  
// Ctrl+G | Delete
#define  K_CTRL_G   7  
// Ctrl+H | Backspace
#define  K_CTRL_H   8  
// Ctrl+I | Tab
#define  K_CTRL_I   9  
// Ctrl+J
#define  K_CTRL_J  10  
// Ctrl+K
#define  K_CTRL_K  11  
// Ctrl+L
#define  K_CTRL_L  12  
// Ctrl+M | Return
#define  K_CTRL_M  13  
// Ctrl+N
#define  K_CTRL_N  14  
// Ctrl+O
#define  K_CTRL_O  15  
// Ctrl+P
#define  K_CTRL_P  16  
// Ctrl+Q
#define  K_CTRL_Q  17  
// Ctrl+R | Page up
#define  K_CTRL_R  18  
// Ctrl+S | Left arrow
#define  K_CTRL_S  19  
// Ctrl+T
#define  K_CTRL_T  20  
// Ctrl+U
#define  K_CTRL_U  21  
// Ctrl+V | Insert
#define  K_CTRL_V  22  
// Ctrl+W | Ctrl+End
#define  K_CTRL_W  23  
// Ctrl+X | Down arrow
#define  K_CTRL_X  24  
// Ctrl+Y
#define  K_CTRL_Y  25  
// Ctrl+Z | Ctrl+left arrow
#define  K_CTRL_Z  26  
                       ** Alt+Letter keys **

#define  K_ALT_A  286  
#define  K_ALT_B  304  
#define  K_ALT_C  302  
#define  K_ALT_D  288  
#define  K_ALT_E  274  
#define  K_ALT_F  289  
#define  K_ALT_G  290  
#define  K_ALT_H  291  
#define  K_ALT_I  279  
#define  K_ALT_J  292  
#define  K_ALT_K  293  
#define  K_ALT_L  294  
#define  K_ALT_M  306  
#define  K_ALT_N  305  
#define  K_ALT_O  280  
#define  K_ALT_P  281  
#define  K_ALT_Q  272  
#define  K_ALT_R  275  
#define  K_ALT_S  287  
#define  K_ALT_T  276  
#define  K_ALT_U  278  
#define  K_ALT_V  303  
#define  K_ALT_W  273  
#define  K_ALT_X  301  
#define  K_ALT_Y  277  
#define  K_ALT_Z  300  
#define  K_ALT_1  376  
#define  K_ALT_2  377  
#define  K_ALT_3  378  
#define  K_ALT_4  379  
#define  K_ALT_5  380  
#define  K_ALT_6  381  
#define  K_ALT_7  382  
#define  K_ALT_8  383  
#define  K_ALT_9  384  
#define  K_ALT_0  385  

*******************************************************************************
* Function keys F1 - F12
*******************************************************************************

// F1 | Ctrl+Backslash
#define  K_F1        28  
#define  K_F2        -1  
#define  K_F3        -2  
#define  K_F4        -3  
#define  K_F5        -4  
#define  K_F6        -5  
#define  K_F7        -6  
#define  K_F8        -7  
#define  K_F9        -8  
#define  K_F10       -9  
#define  K_F11      -40  
#define  K_F12      -41  
                         ** Shift + Function keys

#define  K_SH_F1    -10  
#define  K_SH_F2    -11  
#define  K_SH_F3    -12  
#define  K_SH_F4    -13  
#define  K_SH_F5    -14  
#define  K_SH_F6    -15  
#define  K_SH_F7    -16  
#define  K_SH_F8    -17  
#define  K_SH_F9    -18  
#define  K_SH_F10   -19  
#define  K_SH_F11   -42  
#define  K_SH_F12   -43  
                         ** Ctrl + Function keys **
#define  K_CTRL_F1  -20  
#define  K_CTRL_F2  -21  
#define  K_CTRL_F3  -22  
#define  K_CTRL_F4  -23  
#define  K_CTRL_F5  -24  
#define  K_CTRL_F6  -25  
#define  K_CTRL_F7  -26  
#define  K_CTRL_F8  -27  
#define  K_CTRL_F9  -28  
#define  K_CTRL_F10 -29  
#define  K_CTRL_F11 -44  
#define  K_CTRL_F12 -45  
                         ** Alt + Function keys **
#define  K_ALT_F1   -30  
#define  K_ALT_F2   -31  
#define  K_ALT_F3   -32  
#define  K_ALT_F4   -33  
#define  K_ALT_F5   -34  
#define  K_ALT_F6   -35  
#define  K_ALT_F7   -36  
#define  K_ALT_F8   -37  
#define  K_ALT_F9   -38  
#define  K_ALT_F10  -39  
#define  K_ALT_F11  -46  
#define  K_ALT_F12  -47  

*******************************************************************************
* Keys in the numeric keypad
*******************************************************************************

#define  KP_CTRL_5         399  
#define  KP_CTRL_SLASH     405  
#define  KP_CTRL_ASTERISK  406  
#define  KP_CTRL_MINUS     398  
#define  KP_CTRL_PLUS      400  
#define  KP_ALT_5            5  
#define  KP_ALT_SLASH      420  
#define  KP_ALT_ASTERISK   311  
#define  KP_ALT_MINUS      330  
#define  KP_ALT_PLUS       334  
#define  KP_ALT_ENTER      422  


// Inkey.ch is included
#define  _INKEY_CH              

#endif                          // #ifndef _INKEY_CH

// * EOF *
