//////////////////////////////////////////////////////////////////////
//
//  SERVICE.CH
//
//  Copyright:
//      Alaska Software, (c) 2002-2023. All rights reserved.         
//  
//  Contents:
//      #define constants for the class ServiceController and ServiceApp
//      Additionally this file contains a command layer for implementing
//      a service application and service comand application.
//   
//  Remarks:
//       When assigning values to the service classes attributes always define
//       constants from SERVICE.CH should be used. The values of the contants
//       may vary in future versions of Xbase++.
//   
//////////////////////////////////////////////////////////////////////


#ifndef  _SERVICE_CH
// Service.ch is not included

// service types
#define SERVICE_WIN32_OWN_PROCESS      0x00000010
#define SERVICE_INTERACTIVE_PROCESS    0x00000100


// service start types
#define SERVICE_AUTO_START             0x00000002
#define SERVICE_DEMAND_START           0x00000003
#define SERVICE_DISABLED               0x00000004

// service error control on system boot.
#define SERVICE_ERROR_IGNORE           0x00000000
#define SERVICE_ERROR_NORMAL           0x00000001
#define SERVICE_ERROR_SEVERE           0x00000002
#define SERVICE_ERROR_CRITICAL         0x00000003


//
// Command to add a new service controller
//
#xcommand SERVICE  NAME           <cServiceName>;
                  [CLASSNAME      <cServiceClassName>   ];
                  [DISPLAYNAME    <cServiceDisplayName> ];
                  [SERVICEPATH    <cServicePath>        ];
                  [USERNAME       <cServiceUserName>    ];
                  [PASSWORD       <cServicePassword>    ];
                  [STARTPARAM     <cServiceStartParam>  ];
                  [LOGGER         <oLogger>             ];
     => ServiceController():addController(   <cServiceName>          , ;
                                           [ <cServiceDisplayName> ] , ;
                                           [ <cServicePath>        ] , ;
                                           [ <cServiceUserName>    ] , ;
                                           [ <cServicePassword>    ] , ;
                                           [ <cServiceStartParam>  ] , ;
                                           [ <oLogger>             ] )

//
// Commands for controlling a service
//
#xcommand SERVICE INSTALL <cServiceName>      ;
    => ServiceController():install( <cServiceName> )

#xcommand SERVICE UNINSTALL <cServiceName>    ;
    => ServiceController():uninstall( <cServiceName> )

#xcommand SERVICE START <cServiceName>        ;
    => ServiceController():start( <cServiceName> )

#xcommand SERVICE STOP <cServiceName>         ;
    => ServiceController():stop( <cServiceName> )

#xcommand SERVICE PAUSE <cServiceName>        ;
    => ServiceController():pause( <cServiceName> )

#xcommand SERVICE CONTINUE <cServiceName>      ;
    => ServiceController():Continue( <cServiceName> )

#xcommand SERVICE INTERROGATE <cServiceName>  ;
    => ServiceController():interrogate( <cServiceName> )

//
// Commands for callback registration
//
#xcommand ON SERVICE MAIN <MainFunc> ;
      =>   ServiceApp():main        := {|aParam|<MainFunc>( aParam )}

#xcommand ON SERVICE PAUSE <PauseFunc> ;
      =>   ServiceApp():pause       := {| |<PauseFunc>()}

#xcommand ON SERVICE CONTINUE <ContinueFunc> ;
      =>   ServiceApp():continue := {| | <ContinueFunc>()}

#xcommand ON SERVICE STOP    <StopFunc>;
      =>   ServiceApp():stop        := {| | <StopFunc>()}

//
// Command for starting a service and querying status
//
#xcommand SERVICE EXECUTE [<cServiceClassName>] => ServiceApp():start( [<cServiceClassName>] )

#xcommand SERVICE STATUS <cServiceName> INTO <oServiceControl>   ;
      => <oServiceControl> := ServiceController():getUpdatedControl( <cServiceName> ) 

#xcommand SERVICE ALL INTO <aNames> => ServiceQueryNames( <aNames> )

// Status messages for service control actions
#define SERVICE_MSG_CREATE_SUCCESS              1024
#define SERVICE_MSG_CREATE_ERROR                1025
#define SERVICE_MSG_CREATE_NO_CLASSOBJECT       1026
#define SERVICE_MSG_DELETE_SUCCESS              1027
#define SERVICE_MSG_DELETE_ERROR                1028
#define SERVICE_MSG_START_SUCCESS               1029
#define SERVICE_MSG_START_ERROR                 1030
#define SERVICE_MSG_PAUSE_SUCCESS               1031
#define SERVICE_MSG_PAUSE_ERROR                 1032
#define SERVICE_MSG_STOP_SUCCESS                1033
#define SERVICE_MSG_STOP_ERROR                  1034
#define SERVICE_MSG_CONTINUE_SUCCESS            1035
#define SERVICE_MSG_CONTINUE_ERROR              1036
#define SERVICE_MSG_INTERROGATE_SUCCESS         1037
#define SERVICE_MSG_INTERROGATE_ERROR           1038
#define SERVICE_MSG_WIN9X                       1039
#define SERVICE_MSG_ALLREADYINSTALLED_ERROR     1040


#endif  // #ifndef _SERVICE_CH

// * EOF *

