//////////////////////////////////////////////////////////////////////
//
//  SOCKET.CH
//
//  Copyright:
//      Alaska Software, (c) 2013-2023. All rights reserved.         
//  
//  Contents:
//      #define constants for Xbase++ Socket functions
//   
//////////////////////////////////////////////////////////////////////



// Socket.ch is not included
#ifndef __SOCKET_CH__

#undef IPPROTO_GGP
#undef AF_MAX
#undef AF_IPX

// Protocols
#define IPPROTO_IP              0
#define IPPROTO_ICMP            1
#define IPPROTO_GGP             2
#define IPPROTO_TCP             6
#define IPPROTO_PUP             12
#define IPPROTO_UDP             17
#define IPPROTO_IDP             22
#define IPPROTO_ND              77

#ifndef INADDR_ANY

// Special addresses
#define INADDR_ANY              0x00000000
#define INADDR_LOOPBACK         0x7f000001
#define INADDR_BROADCAST        0xffffffff
#define INADDR_NONE             0xffffffff
#endif

// Socket options on the IP level
#define IP_OPTIONS                 1
#define IP_MULTICAST_IF            2
#define IP_MULTICAST_TTL           3
#define IP_MULTICAST_LOOP          4
#define IP_ADD_MEMBERSHIP          5
#define IP_DROP_MEMBERSHIP         6

#define IP_DEFAULT_MULTICAST_TTL   1
#define IP_DEFAULT_MULTICAST_LOOP  1
#define IP_MAX_MEMBERSHIPS         20

// Invalid socket and socket error
#ifndef INVALID_SOCKET
#define INVALID_SOCKET -1
#define SOCKET_ERROR   -1
#endif

// Types
#define SOCK_STREAM     1
#define SOCK_DGRAM      2
#define SOCK_RAW        3
#define SOCK_RDM        4
#define SOCK_SEQPACKET  5

// Option flags per-socket
#define SO_DEBUG        0x0001
#define SO_ACCEPTCONN   0x0002
#define SO_REUSEADDR    0x0004
#define SO_KEEPALIVE    0x0008
#define SO_DONTROUTE    0x0010
#define SO_BROADCAST    0x0020
#define SO_USELOOPBACK  0x0040
#define SO_LINGER       0x0080
#define SO_OOBINLINE    0x0100

#ifndef SO_DONTLINGER
#define SO_DONTLINGER   0xff7f
#endif

// Additional options
#define SO_SNDBUF       0x1001
#define SO_RCVBUF       0x1002
#define SO_SNDLOWAT     0x1003
#define SO_RCVLOWAT     0x1004
#define SO_SNDTIMEO     0x1005
#define SO_RCVTIMEO     0x1006
#define SO_ERROR        0x1007
#define SO_TYPE         0x1008

// TCP options
#define TC_NODELAY      0x0200

// Address families
#define AF_UNSPEC       0
#define AF_UNIX         1
#define AF_INET         2
#define AF_IMPLINK      3
#define AF_PUP          4
#define AF_CHAOS        5
#define AF_IPX          6
#define AF_NS           6
#define AF_ISO          7
#define AF_OSI          AF_ISO
#define AF_ECMA         8
#define AF_DATAKIT      9
#define AF_CCITT        10
#define AF_SNA          11
#define AF_DECnet       12
#define AF_DLI          13
#define AF_LAT          14
#define AF_HYLINK       15
#define AF_APPLETALK    16
#define AF_NETBIOS      17
#define AF_VOICEVIEW    18

#define AF_MAX          19

// HOSTINFO array member
#define HOSTINFO_SIZE   5
#define HOSTINFO_CNAME  1
#define HOSTINFO_ALIAS  2
#define HOSTINFO_NTYPE  3
#define HOSTINFO_NLEN   4
#define HOSTINFO_ADDR   5

// SERVINFO array member
#define SERVINFO_SIZE   4
#define SERVINFO_CNAME  1
#define SERVINFO_ALIAS  2
#define SERVINFO_NPORT  3
#define SERVINFO_CPROT  4

// PROTINFO array member
#define PROTINFO_SIZE   3
#define PROTINFO_CNAME  1
#define PROTINFO_ALIAS  2
#define PROTINFO_NUMBER 3

// IP address array member
#define IPADDR_SIZE     3
#define IPADDR_FAMILY   1
#define IPADDR_PORT     2
#define IPADDR_ADDR     3


// Send/receive flags
#define MSG_NORMAL      0x0
#define MSG_OOB         0x1
#define MSG_PEEK        0x2
#define MSG_DONTROUTE   0x4


//
// Error management
//

#define WSABASEERR              10000

// Windows Sockets definitions of regular error constants
#define WSAEINTR                (WSABASEERR+4)
#define WSAEBADF                (WSABASEERR+9)
#define WSAEACCES               (WSABASEERR+13)
#define WSAEFAULT               (WSABASEERR+14)
#define WSAEINVAL               (WSABASEERR+22)
#define WSAEMFILE               (WSABASEERR+24)

// Windows Sockets definitions of regular Berkeley error constants
#define WSAEWOULDBLOCK          (WSABASEERR+35)
#define WSAEINPROGRESS          (WSABASEERR+36)
#define WSAEALREADY             (WSABASEERR+37)
#define WSAENOTSOCK             (WSABASEERR+38)
#define WSAEDESTADDRREQ         (WSABASEERR+39)
#define WSAEMSGSIZE             (WSABASEERR+40)
#define WSAEPROTOTYPE           (WSABASEERR+41)
#define WSAENOPROTOOPT          (WSABASEERR+42)
#define WSAEPROTONOSUPPORT      (WSABASEERR+43)
#define WSAESOCKTNOSUPPORT      (WSABASEERR+44)
#define WSAEOPNOTSUPP           (WSABASEERR+45)
#define WSAEPFNOSUPPORT         (WSABASEERR+46)
#define WSAEAFNOSUPPORT         (WSABASEERR+47)
#define WSAEADDRINUSE           (WSABASEERR+48)
#define WSAEADDRNOTAVAIL        (WSABASEERR+49)
#define WSAENETDOWN             (WSABASEERR+50)
#define WSAENETUNREACH          (WSABASEERR+51)
#define WSAENETRESET            (WSABASEERR+52)
#define WSAECONNABORTED         (WSABASEERR+53)
#define WSAECONNRESET           (WSABASEERR+54)
#define WSAENOBUFS              (WSABASEERR+55)
#define WSAEISCONN              (WSABASEERR+56)
#define WSAENOTCONN             (WSABASEERR+57)
#define WSAESHUTDOWN            (WSABASEERR+58)
#define WSAETOOMANYREFS         (WSABASEERR+59)
#define WSAETIMEDOUT            (WSABASEERR+60)
#define WSAECONNREFUSED         (WSABASEERR+61)
#define WSAELOOP                (WSABASEERR+62)
#define WSAENAMETOOLONG         (WSABASEERR+63)
#define WSAEHOSTDOWN            (WSABASEERR+64)
#define WSAEHOSTUNREACH         (WSABASEERR+65)
#define WSAENOTEMPTY            (WSABASEERR+66)
#define WSAEPROCLIM             (WSABASEERR+67)
#define WSAEUSERS               (WSABASEERR+68)
#define WSAEDQUOT               (WSABASEERR+69)
#define WSAESTALE               (WSABASEERR+70)
#define WSAEREMOTE              (WSABASEERR+71)

#define WSAEDISCON              (WSABASEERR+101)

// Extended Windows Sockets error constant definitions
#define WSASYSNOTREADY          (WSABASEERR+91)
#define WSAVERNOTSUPPORTED      (WSABASEERR+92)
#define WSANOTINITIALISED       (WSABASEERR+93)


// Error return codes from gethostbyname() and gethostbyaddr()
// (when using the resolver). Note that these errors are
// retrieved via WSAGetLastError() and must therefore follow
// the rules for avoiding clashes with error numbers from
// specific implementations or language run-time systems.
// For this reason the codes are based at WSABASEERR+1001.
// Note also that [WSA]NO_ADDRESS is defined only for
// compatibility purposes.

// Authoritative Answer: Host not found
#define WSAHOST_NOT_FOUND       (WSABASEERR+1001)
#define HOST_NOT_FOUND          WSAHOST_NOT_FOUND

// Non-Authoritative: Host not found, or SERVERFAIL
#define WSATRY_AGAIN            (WSABASEERR+1002)
#define TRY_AGAIN               WSATRY_AGAIN

// Non recoverable errors, FORMERR, REFUSED, NOTIMP
#define WSANO_RECOVERY          (WSABASEERR+1003)
#define NO_RECOVERY             WSANO_RECOVERY

// Valid name, no data record of requested type
#define WSANO_DATA              (WSABASEERR+1004)
#define NO_DATA                 WSANO_DATA

// no address, look for MX record
#define WSANO_ADDRESS           WSANO_DATA
#define NO_ADDRESS              WSANO_ADDRESS

// WinSock 2 extension -- manifest constants for shutdown()
#define SD_RECEIVE      0x00
#define SD_SEND         0x01
#define SD_BOTH         0x02

// Location of store when selecting a certificate
#define CERTIFICATE_STORE_LOCATION_USER            0x01
#define CERTIFICATE_STORE_LOCATION_LOCAL_MACHINE   0x02
#define CERTIFICATE_STORE_LOCATION_CURRENT_SERVICE 0x03
#define CERTIFICATE_STORE_LOCATION_STORE_USERS     0x04

// Client connection modes
#define CONNECT_PLAIN             1
#define CONNECT_SSL               2
#define CONNECT_SSL_VIA_PORT      CONNECT_SSL
#define CONNECT_SSL_VIA_PROTOCOL  3

// SSL negotiation behaviour
#define CERTIFICATE_ACCEPT_UNKNOWN_AUTHORITY   0x00000001
#define CERTIFICATE_DO_NOT_VALIDATE            0x00000002

// Socket.ch is included
#define __SOCKET_CH__

#endif // #ifndef __SOCKET_CH__
