//////////////////////////////////////////////////////////////////////
//
//  VT100.CH
//
//  Copyright:
//     Alaska Software, (c) 1998-2023. All rights reserved.         
//  
//  Contents:
//     #define constants for console output using the VT100 
//     terminal emulation
//   
//////////////////////////////////////////////////////////////////////


#ifndef  _VT100_CH
#define  _VT100_CH

#include "os.ch"

#define VT_ESC             Chr(27)
#define VT_BELL            Chr(7)

//
// Platfrom support for VT100 escape sequences
//
#xtranslate IsVT100()     => (Os(OS_PRODUCT)=="WIN10" .AND. Val(SubStr(Os(OS_VERSION), 1, 4))>=1511)

//
// Cursor positioning
//
// Cursor up
#xtranslate VT_CUU          => VT_ESC+"[A"              
#xtranslate VT_CUU(<n>)     => VT_ESC+"["+#<n>+"A"

// Cursor down
#xtranslate VT_CUD          => VT_ESC+"[B"              
#xtranslate VT_CUD(<n>)     => VT_ESC+"["+#<n>+"B"

// Cursor forward/right
#xtranslate VT_CUF          => VT_ESC+"[C"              
#xtranslate VT_CUF(<n>)     => VT_ESC+"["+#<n>+"C"

// Cursor backward/left
#xtranslate VT_CUB          => VT_ESC+"[D"              
#xtranslate VT_CUB(<n>)     => VT_ESC+"["+#<n>+"D"

// Cursor next line
#xtranslate VT_CNL          => VT_ESC+"[E"              
#xtranslate VT_CNL(<n>)     => VT_ESC+"["+#<n>+"E"

// Cursor previous line
#xtranslate VT_CPL          => VT_ESC+"[F"              
#xtranslate VT_CPL(<n>)     => VT_ESC+"["+#<n>+"F"

// Cursor horiz. absolute
#xtranslate VT_CHA          => VT_ESC+"[G"              
#xtranslate VT_CHA(<n>)     => VT_ESC+"["+#<n>+"G"

// Vert. line position absolute
#xtranslate VT_VPA          => VT_ESC+"[d"              
#xtranslate VT_VPA(<n>)     => VT_ESC+"["+#<n>+"d"

// Absolute cursor position
#xtranslate VT_CUP          => VT_ESC+"[H"  
#xtranslate VT_CUP(<y>,<x>) => VT_ESC+"["+#<y>+";"+#<x>+"H"  

// Reverse index/one line up
#define VT_RI               VT_ESC+"M"                 

// Save cursor position
#define VT_DECSC            VT_ESC+"7"                 

// Restore cursor position
#define VT_DECSR            VT_ESC+"8"                 


//
// Cursor visibility
//
// Enable/disable blinking
#define VT_ATT160ON       VT_ESC+"[?12h"              
#define VT_ATT160OFF      VT_ESC+"[?12l"              

// Show/hide cursor
#define VT_DECTCEMON      VT_ESC+"[?25h"              
#define VT_DECTCEMOFF     VT_ESC+"[?25l"              


//
// Viewport positioning
//
// Scroll up or down
#xtranslate VT_SU          => VT_ESC+"[S"  
#xtranslate VT_SU(<n>)     => VT_ESC+"["+#<n>+"S"  
#xtranslate VT_SD          => VT_ESC+"[T"  
#xtranslate VT_SD(<n>)     => VT_ESC+"["+#<n>+"T"  


//
// Text modification
//
// Insert character
#xtranslate VT_ICH         => VT_ESC+"[@"  
#xtranslate VT_ICH(<n>)    => VT_ESC+"["+#<n>+"@"  

// Delete character
#xtranslate VT_DCH         => VT_ESC+"[P"  
#xtranslate VT_DCH(<n>)    => VT_ESC+"["+#<n>+"P"  

// Erase character
#xtranslate VT_ECH         => VT_ESC+"[X"  
#xtranslate VT_ECH(<n>)    => VT_ESC+"["+#<n>+"X"  

// Insert line
#xtranslate VT_IL          => VT_ESC+"[L"  
#xtranslate VT_IL(<n>)     => VT_ESC+"["+#<n>+"L"  

// Delete line
#xtranslate VT_DL          => VT_ESC+"[M"  
#xtranslate VT_DL(<n>)     => VT_ESC+"["+#<n>+"M"  

// Erase in display (0=erase from cursor to end
// of screen, 1=erase from start of screen to 
// cursor, 2=erase screen)
#xtranslate VT_ED          => VT_ESC+"[J"  
#xtranslate VT_ED(<n>)     => VT_ESC+"["+#<n>+"J"  

// Erase in line (0=erase from cursor to BOL,
// 1=erase from BOL to cursor, 2=erase line)
#xtranslate VT_EL          => VT_ESC+"[K"  
#xtranslate VT_EL(<n>)     => VT_ESC+"["+#<n>+"K"  


//
// Text formatting
// Note: also referred to as SGR (Set Graphics 
// Rendition) commands
//
// Reset all attributes to defaults
#define VT_SGRRESET        VT_ESC+"[0m"  

// Use bright FG color 
#define VT_FGBRIGHT        VT_ESC+"[1m"  

// Switch underline on/off
#define VT_ULON            VT_ESC+"[4m"  
#define VT_ULOFF           VT_ESC+"[24m"  

// FG/BG color swap on/off
#define VT_NEGON           VT_ESC+"[7m"  
#define VT_NEGOFF          VT_ESC+"[27m"  

// Foreground colors
// Default
#define VT_FGBLACK         VT_ESC+"[30m"  
#define VT_FGRED           VT_ESC+"[31m"  
#define VT_FGGREEN         VT_ESC+"[32m"  
#define VT_FGYELLOW        VT_ESC+"[33m"  
#define VT_FGBLUE          VT_ESC+"[34m"  
#define VT_FGMAGENTA       VT_ESC+"[35m"  
#define VT_FGCYAN          VT_ESC+"[36m"  
#define VT_FGWHITE         VT_ESC+"[37m"  

// Bright
#define VT_FGBBLACK        VT_ESC+"[90m"  
#define VT_FGBRED          VT_ESC+"[91m"  
#define VT_FGBGREEN        VT_ESC+"[92m"  
#define VT_FGBYELLOW       VT_ESC+"[93m"  
#define VT_FGBBLUE         VT_ESC+"[94m"  
#define VT_FGBMAGENTA      VT_ESC+"[95m"  
#define VT_FGBCYAN         VT_ESC+"[96m"  
#define VT_FGBWHITE        VT_ESC+"[97m"  

#xtranslate VT_FGRGB(<r>,<g>,<b>) => VT_ESC+"[38;2;"+#<r>+";"+#<g>+";"+#<b>+"m"
#xtranslate VT_FGIDX(<n>)  => VT_ESC+"[38;2;"+#<n>+"m"

#define VT_FGRESET         VT_ESC+"[39m"  

// Background colors
// Default
#define VT_BGBLACK         VT_ESC+"[40m"  
#define VT_BGRED           VT_ESC+"[41m"  
#define VT_BGGREEN         VT_ESC+"[42m"  
#define VT_BGYELLOW        VT_ESC+"[43m"  
#define VT_BGBLUE          VT_ESC+"[44m"  
#define VT_BGMAGENTA       VT_ESC+"[45m"  
#define VT_BGCYAN          VT_ESC+"[46m"  
#define VT_BGWHITE         VT_ESC+"[47m"  

// Bright
#define VT_BGBBLACK        VT_ESC+"[100m"  
#define VT_BGBRED          VT_ESC+"[101m"  
#define VT_BGBGREEN        VT_ESC+"[102m"  
#define VT_BGBYELLOW       VT_ESC+"[103m"  
#define VT_BGBBLUE         VT_ESC+"[104m"  
#define VT_BGBMAGENTA      VT_ESC+"[105m"  
#define VT_BGBCYAN         VT_ESC+"[106m"  
#define VT_BGBWHITE        VT_ESC+"[107m"  

#xtranslate VT_BGRGB(<r>,<g>,<b>) => VT_ESC+"[48;2;"+#<r>+";"+#<g>+";"+#<b>+"m"
#xtranslate VT_BGIDX(<n>)  => VT_ESC+"[38;5;"+#<n>+"m"

#define VT_BGRESET         VT_ESC+"[49m"  


//
// Color palette
//
#xtranslate VT_PALETTE(<n>,<r>,<g>,<b>) => VT_ESC+"]4;"+#<n>+";rgb:"+#<r>+"/"+#<g>+"/"+#<b>+VT_ESC


//
// Tabs
//
// Horizontal tab set
#define VT_HTS             VT_ESC+"H"  

// Cursor horizontal tab (tab forwards/backwards)
#xtranslate VT_CHT         => VT_ESC+"[I"  
#xtranslate VT_CHT(<n>)    => VT_ESC+"["+#<n>+"I"  
#xtranslate VT_CBT         => VT_ESC+"[Z"  
#xtranslate VT_CBT(<n>)    => VT_ESC+"["+#<n>+"Z"  

// Clear tab stop in current or in all column(s)
#define VT_TBC             VT_ESC+"[0g"  
#define VT_TBCALL          VT_ESC+"[3g"  


//
// Character set mapping
//
// Designate DEC Line Drawing
#define VT_DCSDEC          VT_ESC+"(0"  

// Designate US ASCII (default)
#define VT_DCSUSASCII      VT_ESC+"(B"

#define VT_CSDEC_BL        "j"
#define VT_CSDEC_TL        "k"
#define VT_CSDEC_TR        "l"
#define VT_CSDEC_BR        "m"
#define VT_CSDEC_MID       "n"
#define VT_CSDEC_HORZ      "q"
#define VT_CSDEC_MR        "t"
#define VT_CSDEC_ML        "u"
#define VT_CSDEC_BM        "v"
#define VT_CSDEC_TM        "w"
#define VT_CSDEC_VERT      "x"


//
// Alternate screen buffer
//
#define VT_ABUFON          VT_ESC+"[?1049h"  
#define VT_ABUFOFF         VT_ESC+"[?1049l"  


//
// Scrolling margins
//
#xtranslate VT_DECSTBM     => VT_ESC+"[r"  
#xtranslate VT_DECSTBM(<t>,<b>) => VT_ESC+"["+#<t>+";"+#<b>+"r"  


//
// Window title
//
#xtranslate VT_WTITLE()    => VT_ESC+"]2;"+VT_BELL
#xtranslate VT_WTITLE(<c>) => VT_ESC+"]2;"+<c>+VT_BELL


//
// Window width
//
#define VT_DECCOLM132      VT_ESC+"[?3h"  
#define VT_ECCCOLM80       VT_ESC+"[?3l"  


//
// Soft Reset
// This resets cursor visibility (visible), numeric
// keypad (numeric), key mode (normal), top and
// bottom margins (1, console height), character
// set (US ASCII) graphics rendition (default),
// saved cursor position (0,0)
//
#define VT_DECCSTR         VT_ESC+"[!p"  

#endif // #ifndef _VT100_CH
