//////////////////////////////////////////////////////////////////////
//
//  XBP.CH
//
//  Copyright:
//      Alaska Software, (c) 1998-2023. All rights reserved.         
//  
//  Contents:
//      #define constants for Xbase Parts
//   
//////////////////////////////////////////////////////////////////////


// Xbp.ch is not included
#ifndef  _XBP_CH

//****************************************************************************
// Common Settings
//****************************************************************************

// Generic autosize flag
#define XBP_AUTOSIZE                  -1

// State definitions
#define XBP_STATE_NORMAL               1
#define XBP_STATE_HOT                  2
#define XBP_STATE_PRESSED              3
#define XBP_STATE_DISABLED             4
#define XBP_STATE_CUSTOM               128

#define XBP_STATE_AUTO                 (XBP_STATE_CUSTOM -1)

// Alignment definitions
#ifdef __OS2__
#define XBPALIGN_TOP                   0
#define XBPALIGN_LEFT                  0
#define XBPALIGN_BOTTOM             2048
#define XBPALIGN_RIGHT               512
#define XBPALIGN_HCENTER             256
#define XBPALIGN_VCENTER            1024
#define XBPALIGN_WORDBREAK         16384
#endif

#ifdef __WIN32__
#define XBPALIGN_TOP                   0
#define XBPALIGN_LEFT                  0
#define XBPALIGN_BOTTOM                8
#define XBPALIGN_RIGHT                 2
#define XBPALIGN_HCENTER               1
#define XBPALIGN_VCENTER               4
#define XBPALIGN_WORDBREAK            16
#endif

// Frame layout definitions
#define XBPFRAME_NONE                  0
#define XBPFRAME_RECT                  1
#define XBPFRAME_BOX                   2

#define XBPFRAME_RAISED               16
#define XBPFRAME_RECESSED             32
#define XBPFRAME_THICK               128

#define XBPFRAME_DASHED              256
#define XBPFRAME_DOTTED              512

// Line layout definitions
#define XBPLINE_NONE                   1
#define XBPLINE_NORMAL                 2
#define XBPLINE_DASHED                 4
#define XBPLINE_DOTTED                 8

// Style definitions
#define XBP_STYLE_SYSTEMDEFAULT        0
#define XBP_STYLE_PLAIN                1
#define XBP_STYLE_3D                   2
#define XBP_STYLE_FANCY                4
#define XBP_STYLE_DEFAULT              XBP_STYLE_PLAIN

// Defines used for specifying control appearance
#define XBP_APPEARANCE_FLAT           0
#define XBP_APPEARANCE_3D             1

// Defines used for specifying control appearance
#define XBP_ORIENT_HORIZONTAL         1
#define XBP_ORIENT_VERTICAL           2

// Drawing modes used with XBPs
#define XBP_DRAW_NORMAL                0
#define XBP_DRAW_OWNER                 1
#define XBP_DRAW_OWNERADVANCED         2

// Members of the <aInfo> array passed to
// :Draw(), :DrawItem() etc.
#define XBP_DRAWINFO_ITEM              1
#define XBP_DRAWINFO_ACTION            2
#define XBP_DRAWINFO_STATE             3
#define XBP_DRAWINFO_RECT              4
#define XBP_DRAWINFO_AREA              5
#define XBP_DRAWINFO_COLUMN            6

// Drawing actions for XBPs rendered using drawing
// modes XBP_DRAW_OWNER or XBP_DRAW_OWNER_ADVANCED
#define XBP_DRAWACTION_DRAWALL         1
#define XBP_DRAWACTION_SELCHANGE       2
#define XBP_DRAWACTION_FOCUSCHANGE     4
#define XBP_DRAWACTION_DRAWBG          8
#define XBP_DRAWACTION_DRAWFRAME       16
#define XBP_DRAWACTION_DRAWFG          32
#define XBP_DRAWACTION_ERASEBG         64

// Drawing status used with XBPs rendered using drawing
// modes XBP_DRAW_OWNER or XBP_DRAW_OWNER_ADVANCED
#define XBP_DRAWSTATE_NORMAL           0
#define XBP_DRAWSTATE_SELECTED         1
#define XBP_DRAWSTATE_GRAYED           2
#define XBP_DRAWSTATE_DISABLED         4
#define XBP_DRAWSTATE_CHECKED          8
#define XBP_DRAWSTATE_FOCUS            16
#define XBP_DRAWSTATE_DEFAULTITEM      32
#define XBP_DRAWSTATE_HOT              64
#define XBP_DRAWSTATE_COMBOBOXEDIT     4096
#define XBP_DRAWSTATE_HEADER           24576

// Defines used for identifying borders affected
// by or involved in a certain operation
#define XBPBORDER_LEFT                 1
#define XBPBORDER_TOP                  2
#define XBPBORDER_RIGHT                4
#define XBPBORDER_BOTTOM               8

// Defines used with :ModalResult, :ShowModal()
#define XBP_MRESULT_NONE               0
#define XBP_MRESULT_OK                 1
#define XBP_MRESULT_CANCEL             2
#define XBP_MRESULT_RETRY              4
#define XBP_MRESULT_YESTOALL           8
#define XBP_MRESULT_ERROR              (-1)

// Defines used for specifying scroll bars
#define XBP_SCROLLBAR_NONE             0
#define XBP_SCROLLBAR_HORIZ            1
#define XBP_SCROLLBAR_VERT             2

// Defines for specifying effects of a
// drag-and-drop operation
#define XBP_DROPMODE_NONE              0
#define XBP_DROPMODE_COPY              1
#define XBP_DROPMODE_MOVE              2
#define XBP_DROPMODE_LINK              4

// Defines for layout management
#define XBPLAYOUT_NONE                 0
#define XBPLAYOUT_LEFT                 XBPBORDER_LEFT
#define XBPLAYOUT_TOP                  XBPBORDER_TOP
#define XBPLAYOUT_RIGHT                XBPBORDER_RIGHT
#define XBPLAYOUT_BOTTOM               XBPBORDER_BOTTOM

#define XBPLAYOUT_RELLEFT              0x10    
#define XBPLAYOUT_RELBOTTOM            0x20     
#define XBPLAYOUT_RELRIGHT             0x40    
#define XBPLAYOUT_RELTOP               0x80     

#define XBPLAYOUT_CENTERX              (XBPLAYOUT_RELLEFT+0x1000)
#define XBPLAYOUT_CENTERY              (XBPLAYOUT_RELBOTTOM+0x2000)
#define XBPLAYOUT_RELWIDTH             0x100    
#define XBPLAYOUT_RELHEIGHT            0x200    

// Defines for specifying image properties
#define XBP_IMAGE_NORMAL               0
#define XBP_IMAGE_TILED                32
#define XBP_IMAGE_SCALED               64
#define XBP_IMAGE_DISABLED             128

// Visual display indicators supported by
// XbpWindow:IsUICueActive()
#define XBP_UICUE_FOCUS                1
#define XBP_UICUE_SHORTCUT             2

// Defines for specifying balloon tip type, 
// see :ShowBalloonTip()
#define XBP_TIPDEFAULT                  0
#define XBP_TIPINFO                     1
#define XBP_TIPWARNING                  2
#define XBP_TIPERROR                    3
#define XBP_TIPINFOLARGE                4
#define XBP_TIPWARNINGLARGE             5
#define XBP_TIPERRORLARGE               6

// Defines for controlling input modes, eg. for
// pen and touch input
#define XBP_INPUTMODE_SYSTEMDEFAULT           0x00
#define XBP_INPUTMODE_NOTOUCHGESTURES         0x01
#define XBP_INPUTMODE_TOUCHGESTURES           0x02
#define XBP_INPUTMODE_NOPENFLICKS             0x04
#define XBP_INPUTMODE_NOPRESSANDHOLD          0x08
#define XBP_INPUTMODE_NOPENTAPFEEDBACK        0x10
#define XBP_INPUTMODE_NOPENBUTTONFEEDBACK     0x20

#define XBP_INPUTMODEGF_NOZOOMGESTURE         0x00010000
#define XBP_INPUTMODEGF_NOPANGESTURE          0x00020000
#define XBP_INPUTMODEGF_NOROTATEGESTURE       0x00040000
#define XBP_INPUTMODEGF_NOTWOFINGERTAPGESTURE 0x00080000
#define XBP_INPUTMODEGF_NOPRESSANDTAPGESTURE  0x00100000
#define XBP_INPUTMODEGF_NOONEFINGERPAN_HORZ   0x00200000
#define XBP_INPUTMODEGF_NOONEFINGERPAN_VERT   0x00400000
#define XBP_INPUTMODEGF_PANWITHGUTTER         0x00800000
#define XBP_INPUTMODEGF_NOPANINERTIA          0x01000000
#define XBP_INPUTMODEGF_NOLEGACYSUPPORT       0x02000000


//****************************************************************************
// Parameters for generic messages
//****************************************************************************
// Defines for mp1 and mp2 after the event xbeP_Quit
#define XBP_QUITCAUSE_SYSTEMSHUTDOWN   0

#define XBP_REJECT                     0
#define XBP_ALLOW                      1

// Defines for mp1 after the event xbeP_SystemPropertyChanged
#define XBP_DISPLAYRESOLUTION          1
#define XBP_SYSTEMPARAMETER            2

// Defines for xbeP_SystemPowerStatus event
#define XBP_POWERQUERY_GRANT           1
#define XBP_POWERQUERY_DENY            0x424D5144

// Defines for xbeP_Gesture event
#define XBP_GESTURE_ZOOM               3
#define XBP_GESTURE_PAN                4
#define XBP_GESTURE_ROTATE             5
#define XBP_GESTURE_TWOFINGERTAP       6
#define XBP_GESTURE_PRESSANDTAP        7

// Members of the <aInfo> array passed to
// :Gesture()
#define XBP_GESTUREINFO_POS            1
#define XBP_GESTUREINFO_LASTPOS        2
#define XBP_GESTUREINFO_STARTPOS       3
#define XBP_GESTUREINFO_ARGS           4
#define XBP_GESTUREINFO_LASTARGS       5
#define XBP_GESTUREINFO_STARTARGS      6
#define XBP_GESTUREINFO_STATE          7

// Gesture states defined 
#define XBP_GESTURESTATE_HASINERTIA    2
#define XBP_GESTURESTATE_BEGIN         1
#define XBP_GESTURESTATE_END           4

//****************************************************************************
// XbpCrt Settings
//****************************************************************************

// XbpCrt:MouseMode Definitions
// mp1 contains text coordinates
// mp1 := { nRow, nCol }
#define XBPCRT_MOUSEMODE_VIO           1
// mp1 contains graphic coordinates
// mp1 := { nX, nY }
#define XBPCRT_MOUSEMODE_PM            2

//****************************************************************************
// Constants for XbpFont
//****************************************************************************

// Defines for XbpFont:WeightClass
#ifdef __OS2__
#define XBPFONT_WEIGHT_DONT_CARE       0
#define XBPFONT_WEIGHT_ULTRA_LIGHT     1
#define XBPFONT_WEIGHT_EXTRA_LIGHT     2
#define XBPFONT_WEIGHT_LIGHT           3
#define XBPFONT_WEIGHT_SEMI_LIGHT      4
#define XBPFONT_WEIGHT_NORMAL          5
#define XBPFONT_WEIGHT_SEMI_BOLD       6
#define XBPFONT_WEIGHT_BOLD            7
#define XBPFONT_WEIGHT_EXTRA_BOLD      8
#define XBPFONT_WEIGHT_ULTRA_BOLD      9
#endif

#ifdef __WIN32__
#define XBPFONT_WEIGHT_DONT_CARE       0
#define XBPFONT_WEIGHT_ULTRA_LIGHT     100
#define XBPFONT_WEIGHT_EXTRA_LIGHT     200
#define XBPFONT_WEIGHT_LIGHT           300
#define XBPFONT_WEIGHT_SEMI_LIGHT      300
#define XBPFONT_WEIGHT_NORMAL          400
#define XBPFONT_WEIGHT_SEMI_BOLD       600
#define XBPFONT_WEIGHT_BOLD            700
#define XBPFONT_WEIGHT_EXTRA_BOLD      800
#define XBPFONT_WEIGHT_ULTRA_BOLD      900
#endif

// Defines for XbpFont:WidthClass
#define XBPFONT_WIDTH_DONT_CARE        0
#define XBPFONT_WIDTH_ULTRA_CONDENSED  1
#define XBPFONT_WIDTH_EXTRA_CONDENSED  2
#define XBPFONT_WIDTH_CONDENSED        3
#define XBPFONT_WIDTH_SEMI_CONDENSED   4
#define XBPFONT_WIDTH_NORMAL           5
#define XBPFONT_WIDTH_SEMI_EXPANDED    6
#define XBPFONT_WIDTH_EXPANDED         7
#define XBPFONT_WIDTH_EXTRA_EXPANDED   8
#define XBPFONT_WIDTH_ULTRA_EXPANDED   9

//****************************************************************************
// Constants for the return value of oXbp:status()
//****************************************************************************
#define XBP_STAT_INIT                  0
#define XBP_STAT_CREATE                1
#define XBP_STAT_FAILURE               2

//****************************************************************************
// Constants for XbpSysWindow:display() and XbpWindow:setModalState()
//****************************************************************************
#define XBP_DISP_MODELESS              1
#define XBP_DISP_APPMODAL              2
#define XBP_DISP_SYSMODAL              3

//****************************************************************************
// Constants for XbpWindow:Group
//****************************************************************************
#define XBP_BEGIN_GROUP                1
#define XBP_WITHIN_GROUP               2
#define XBP_END_GROUP                  3
#define XBP_NO_GROUP                   4

//****************************************************************************
// Constants for XbpWindow:InvalidateRect()
//****************************************************************************
#define XBP_INVREGION_LOCK             0x10000
#define XBP_INVREGION_DISCARD          0x20000
#define XBP_INVREGION_RELEASE          0x40000
#define XBP_INVREGION_AND              1
#define XBP_INVREGION_OR               2
#define XBP_INVREGION_XOR              3
#define XBP_INVREGION_DIFF             4

//****************************************************************************
// Constants for Presentation Parameter
//****************************************************************************

// Generic presentation parameter
#define XBP_PP_FGCLR                   2
#define XBP_PP_BGCLR                   4
#define XBP_PP_HILITE_FGCLR            6
#define XBP_PP_HILITE_BGCLR            8
#define XBP_PP_DISABLED_FGCLR          10
#define XBP_PP_DISABLED_BGCLR          12
#define XBP_PP_BORDER_CLR              14
#define XBP_PP_COMPOUNDNAME            15
#define XBP_PP_FONT                    16
#define XBP_PP_ACTIVE_CLR              19
#define XBP_PP_INACTIVE_CLR            21
#define XBP_PP_ACTIVETEXT_FGCLR        23
#define XBP_PP_ACTIVETEXT_BGCLR        25
#define XBP_PP_INACTIVETEXT_FGCLR      27
#define XBP_PP_INACTIVETEXT_BGCLR      29
#define XBP_PP_CAPTION                 50
#define XBP_PP_ALIGNMENT               52
#define XBP_PP_ORIGIN                  300

// Special presentation parameter for XbpMenu.
#define XBP_PP_MENU_FGCLR              32
#define XBP_PP_MENU_BGCLR              34
#define XBP_PP_MENU_HILITE_FGCLR       36
#define XBP_PP_MENU_HILITE_BGCLR       38
#define XBP_PP_MENU_DISABLED_FGCLR     40
#define XBP_PP_MENU_DISABLED_BGCLR     42

//****************************************************************************
// Constants for XbpWindow:SetPointer()
//****************************************************************************
#define XBPWINDOW_POINTERTYPE_POINTER     1
#define XBPWINDOW_POINTERTYPE_SYSPOINTER  2
#define XBPWINDOW_POINTERTYPE_ICON        3
#define XBPWINDOW_POINTERTYPE_ANIMPOINTER 4
#define XBPWINDOW_POINTERTYPE_OSHANDLE    5

//****************************************************************************
// Constants for XbpMenuBar and XbpMenu
//****************************************************************************

// Defines for the MenuItem structure (-> oMenu:addItem() )
#define XBPMENUBAR_MENITEM_CAPTION     1
#define XBPMENUBAR_MENITEM_BLOCK       2
#define XBPMENUBAR_MENITEM_STYLE       3
#define XBPMENUBAR_MENITEM_ATTRIB      4

// Defines for MenuItem styles (XBPMENUBAR_MENITEM_STYLE).
#define XBPMENUBAR_MIS_STATIC          256

// These MenuItem styles are valid if
// Menuitem[ XBPMENUBAR_MENITEM_CAPTION ] == NIL
#define XBPMENUBAR_MIS_SEPARATOR       4
#define XBPMENUBAR_MIS_BUTTONSEPARATOR 512
#define XBPMENUBAR_MIS_BREAK           1024
#define XBPMENUBAR_MIS_BREAKSEPARATOR  2048

// Defines for MenuItem attributes (XBPMENUBAR_MENITEM_ATTRIB).
#define XBPMENUBAR_MIA_NODISMISS       32
#define XBPMENUBAR_MIA_FRAMED          4096
#define XBPMENUBAR_MIA_CHECKED         8192
#define XBPMENUBAR_MIA_DISABLED        16384
#define XBPMENUBAR_MIA_HILITED         32768
#define XBPMENUBAR_MIA_DEFAULT         65536
#define XBPMENUBAR_MIA_OWNERDRAW       131072


//****************************************************************************
// Constants for XbpMenu:PopUp() options (must be added together).
//****************************************************************************

// Menu constrains on screen.
#define XBPMENU_PU_HCONSTRAIN          2
#define XBPMENU_PU_VCONSTRAIN          4

// Preselected mouse button
#define XBPMENU_PU_NONE                0
#define XBPMENU_PU_MOUSE_LBDOWN        8
#define XBPMENU_PU_MOUSE_RBDOWN        16
#define XBPMENU_PU_MOUSE_MBDOWN        24

// Usable mouse button / keyboard.
#define XBPMENU_PU_MOUSE_LB            64
#define XBPMENU_PU_MOUSE_RB            128
#define XBPMENU_PU_MOUSE_MB            256
#define XBPMENU_PU_KEYBOARD            512

// Default setting
#ifdef __XBASE2__
#define XBPMENU_PU_DEFAULT    ( XBPMENU_PU_HCONSTRAIN + XBPMENU_PU_VCONSTRAIN + ;
                                XBPMENU_PU_MOUSE_LB + XBPMENU_PU_MOUSE_RB + ;
                                XBPMENU_PU_KEYBOARD )
#else
#define XBPMENU_PU_DEFAULT    ( XBPMENU_PU_HCONSTRAIN + XBPMENU_PU_VCONSTRAIN + \
                                XBPMENU_PU_MOUSE_LB + XBPMENU_PU_MOUSE_RB + \
                                XBPMENU_PU_KEYBOARD )
#endif


//****************************************************************************
// Constants for XbpMicroPS
//****************************************************************************

// Buffer mode
#define XBPMICPS_DRAW_IMMEDIATE             0
#define XBPMICPS_DRAW_BUFFERED              1


//****************************************************************************
// Constants for XbpStatusBar and XbpStatusBarPanel
//****************************************************************************

// Defines controlling Panel auto-sizing, see :Autosize
#define XBPSTATUSBAR_AUTOSIZE_NONE          0
#define XBPSTATUSBAR_AUTOSIZE_SPRING        1
#define XBPSTATUSBAR_AUTOSIZE_CONTENTS      2

// Defines controlling Panel bevels/borders, see :Bevel
#define XBPSTATUSBAR_BEVEL_NONE             0
#define XBPSTATUSBAR_BEVEL_INSET            1
#define XBPSTATUSBAR_BEVEL_RAISED           2

// Panel styles defined, see :Style
#define  XBPSTATUSBAR_PANEL_TEXT            0
#define  XBPSTATUSBAR_PANEL_CAPSLOCK        1
#define  XBPSTATUSBAR_PANEL_NUMLOCK         2
#define  XBPSTATUSBAR_PANEL_INSERT          3
#define  XBPSTATUSBAR_PANEL_SCROLL          4
#define  XBPSTATUSBAR_PANEL_TIME            5
#define  XBPSTATUSBAR_PANEL_DATE            6
#define  XBPSTATUSBAR_PANEL_KANA            7


//****************************************************************************
// Constants for XbpToolBar and XbpToolBarButton
//****************************************************************************

// Toolbar style, see :Style of a toolbar object
#define XBPTOOLBAR_STYLE_STANDARD         0
#define XBPTOOLBAR_STYLE_FLAT             1

// Button value contants, see :Value of a toolbar button object
#define XBPTOOLBAR_BUTTON_UNPRESSED       0
#define XBPTOOLBAR_BUTTON_PRESSED         1

// Button style contants, see :Style of a toolbar button
#define XBPTOOLBAR_BUTTON_DEFAULT         0
#define XBPTOOLBAR_BUTTON_TOGGLE          1
#define XBPTOOLBAR_BUTTON_BUTTONGROUP     2
#define XBPTOOLBAR_BUTTON_SEPARATOR       3
#define XBPTOOLBAR_BUTTON_PLACEHOLDER     4
#define XBPTOOLBAR_BUTTON_DROPDOWN        5

// Constants used with :LoadImageSet()
#define XBPTOOLBAR_STDIMAGES_SMALL        0
#define XBPTOOLBAR_STDIMAGES_LARGE        1
#define XBPTOOLBAR_VIEWIMAGES_SMALL       4
#define XBPTOOLBAR_VIEWIMAGES_LARGE       5
#define XBPTOOLBAR_EXPLORERIMAGES_SMALL   8
#define XBPTOOLBAR_EXPLORERIMAGES_LARGE   9

// Images defined in Explorer image set
#define EXPLORER_IMAGE_ADDTOFAVORITES        (-44)
#define EXPLORER_IMAGE_BACK                  (-41)
#define EXPLORER_IMAGE_FAVORITES             (-43)
#define EXPLORER_IMAGE_FORWARD               (-42)
#define EXPLORER_IMAGE_VIEWTREE              (-45)

// Images defined in standard image set
#ifdef __XPP__
#define STD_IMAGE_COPY                       (-2)
#define STD_IMAGE_CUT                        (-1)
#define STD_IMAGE_DELETE                     (-6)
#define STD_IMAGE_FILENEW                    (-7)
#define STD_IMAGE_FILEOPEN                   (-8)
#define STD_IMAGE_FILESAVE                   (-9)
#define STD_IMAGE_FIND                       (-13)
#define STD_IMAGE_HELP                       (-12)
#define STD_IMAGE_PASTE                      (-3)
#define STD_IMAGE_PRINT                      (-15)
#define STD_IMAGE_PRINTPRE                   (-10)
#define STD_IMAGE_PROPERTIES                 (-11)
#define STD_IMAGE_REDO                       (-5)
#define STD_IMAGE_REPLACE                    (-14)
#define STD_IMAGE_UNDO                       (-4)
#endif

// Images defined in view image set
#ifdef __XPP__
#define VIEW_IMAGE_DETAILS                   (-24)
#define VIEW_IMAGE_LARGEICONS                (-21)
#define VIEW_IMAGE_LIST                      (-23)
#define VIEW_IMAGE_NETCONNECT                (-30)
#define VIEW_IMAGE_NETDISCONNECT             (-31)
#define VIEW_IMAGE_NEWFOLDER                 (-32)
#define VIEW_IMAGE_PARENTFOLDER              (-29)
#define VIEW_IMAGE_SMALLICONS                (-22)
#define VIEW_IMAGE_SORTDATE                  (-27)
#define VIEW_IMAGE_SORTNAME                  (-25)
#define VIEW_IMAGE_SORTSIZE                  (-26)
#define VIEW_IMAGE_SORTTYPE                  (-28)
#endif


//****************************************************************************
// Constants for XbpRTF
//****************************************************************************

// Defines used with instance variable :SelAlignment
#define XBPRTF_ALIGN_LEFT              0
#define XBPRTF_ALIGN_RIGHT             1
#define XBPRTF_ALIGN_CENTER            2

// Contants used with method :Find()
#define XBPRTF_MATCH_WHOLEWORD         2
#define XBPRTF_MATCH_CASE              4
#define XBPRTF_MATCH_NOHILIGHT         8


//****************************************************************************
// Constants for XbpDatePicker
//****************************************************************************

// Date formats defined
#define XBPDP_DATEFORMAT_LONG          0
#define XBPDP_DATEFORMAT_SHORT         1
#define XBPDP_DATEFORMAT_TIME          2
#define XBPDP_DATEFORMAT_CUSTOM        3


//****************************************************************************
// Key State Masks for Mouse Messages
//****************************************************************************

// Currently supported: mp2[1] of xbeM_Wheel
#define XBP_MK_LBUTTON          1
#define XBP_MK_RBUTTON          2
#define XBP_MK_SHIFT            4
#define XBP_MK_CONTROL          8
#define XBP_MK_MBUTTON          16


//****************************************************************************
// Constants for XbpDialog
//****************************************************************************

// Defines for XbpDialog:Border and XbpCrt:border
#define XBPDLG_NO_BORDER                   1
#define XBPDLG_SIZEBORDER                  2
#define XBPDLG_THINBORDER                  3
#define XBPDLG_DLGBORDER                   4
#define XBPDLG_RAISEDBORDERTHICK           5
#define XBPDLG_RAISEDBORDERTHIN            6
#define XBPDLG_RECESSEDBORDERTHICK         7
#define XBPDLG_RECESSEDBORDERTHIN          8
#define XBPDLG_RAISEDBORDERTHICK_FIXED     9
#define XBPDLG_RAISEDBORDERTHIN_FIXED      10
#define XBPDLG_RECESSEDBORDERTHICK_FIXED   11
#define XBPDLG_RECESSEDBORDERTHIN_FIXED    12

// Defines for XbpDialog:Origin
#define XBPDLG_ORIGIN_OWNER                1
#define XBPDLG_ORIGIN_SCREEN               2
#define XBPDLG_ORIGIN_MOUSE                3

// Defines for XBP_PP_ORIGIN
#define XBP_ORIGIN_TOPLEFT                 1
#define XBP_ORIGIN_BOTTOMLEFT              2

// Defines for XbpDialog:SetFrameState()
#define XBPDLG_FRAMESTAT_MINIMIZED         1
#define XBPDLG_FRAMESTAT_MAXIMIZED         2
#define XBPDLG_FRAMESTAT_NORMALIZED        3
#define XBPDLG_FRAMESTAT_KIOSK             4
#define XBPDLG_FRAMESTAT_FULLSCREEN        12


//****************************************************************************
// Constants for XbpStatic
//****************************************************************************

// Defines for XbpStatic:Type
#define XBPSTATIC_TYPE_TEXT                1
#define XBPSTATIC_TYPE_GROUPBOX            2
#define XBPSTATIC_TYPE_ICON                3
#define XBPSTATIC_TYPE_SYSICON             4
#define XBPSTATIC_TYPE_BITMAP              5
#define XBPSTATIC_TYPE_FGNDRECT            6
#define XBPSTATIC_TYPE_BGNDRECT            7
#define XBPSTATIC_TYPE_FGNDFRAME           8
#define XBPSTATIC_TYPE_BGNDFRAME           9
#define XBPSTATIC_TYPE_HALFTONERECT        10
#define XBPSTATIC_TYPE_HALFTONEFRAME       11
#define XBPSTATIC_TYPE_RAISEDBOX           12
#define XBPSTATIC_TYPE_RECESSEDBOX         13
#define XBPSTATIC_TYPE_RAISEDRECT          14
#define XBPSTATIC_TYPE_RECESSEDRECT        15
#define XBPSTATIC_TYPE_RAISEDLINE          16
#define XBPSTATIC_TYPE_RECESSEDLINE        17

// Defines for XbpStatic:Options if
//    XbpStatic:Type := XBPSTATIC_TYPE_TEXT
#define XBPSTATIC_TEXT_LEFT                XBPALIGN_LEFT
#define XBPSTATIC_TEXT_RIGHT               XBPALIGN_RIGHT
#define XBPSTATIC_TEXT_CENTER              XBPALIGN_HCENTER
#define XBPSTATIC_TEXT_TOP                 XBPALIGN_TOP
#define XBPSTATIC_TEXT_VCENTER             XBPALIGN_VCENTER
#define XBPSTATIC_TEXT_BOTTOM              XBPALIGN_BOTTOM
#define XBPSTATIC_TEXT_WORDBREAK           XBPALIGN_WORDBREAK

// Defines for XbpStatic:Options if
//    XbpStatic:Type := XBPSTATIC_TYPE_BITMAP
#define XBPSTATIC_BITMAP_TILED             XBP_IMAGE_TILED
#define XBPSTATIC_BITMAP_SCALED            XBP_IMAGE_SCALED

// Defines for XbpStatic:Options if a raised or recessed
// frame was specified for XbpStatic:Type.
#define XBPSTATIC_FRAMETHIN                1
#define XBPSTATIC_FRAMETHICK               2

// Defines for XbpStatic:Caption if
//   XbpStatic:Type := XBPSTATIC_TYPE_SYSICON  (-> System Icons )
#define XBPSTATIC_SYSICON_DEFAULT          0
#define XBPSTATIC_SYSICON_ARROW            1
#define XBPSTATIC_SYSICON_TEXT             2
#define XBPSTATIC_SYSICON_WAIT             3
#define XBPSTATIC_SYSICON_SIZE             4
#define XBPSTATIC_SYSICON_MOVE             5
#define XBPSTATIC_SYSICON_SIZENWSE         6
#define XBPSTATIC_SYSICON_SIZENESW         7
#define XBPSTATIC_SYSICON_SIZEWE           8
#define XBPSTATIC_SYSICON_SIZENS           9
#define XBPSTATIC_SYSICON_APPICON          10
#define XBPSTATIC_SYSICON_ICONINFORMATION  11
#define XBPSTATIC_SYSICON_ICONQUESTION     12
#define XBPSTATIC_SYSICON_ICONERROR        13
#define XBPSTATIC_SYSICON_ICONWARNING      14
#define XBPSTATIC_SYSICON_ILLEGAL          18
#define XBPSTATIC_SYSICON_FILE             19
#define XBPSTATIC_SYSICON_FOLDER           20
#define XBPSTATIC_SYSICON_MULTFILE         21
#define XBPSTATIC_SYSICON_PROGRAM          22
#define XBPSTATIC_SYSICON_DISPLAY_PTRS     22
#define XBPSTATIC_SYSICON_PENFIRST         23
#define XBPSTATIC_SYSICON_PENLAST          39


//****************************************************************************
// SysColor defines, used together with XBPs but can be passed as well to
// GraSetColor() and XbpPresSpace:SetAttr*(), respectively.
//****************************************************************************

#define XBPSYSCLR_DWMCOLORIZATION          (-63)  
#define XBPSYSCLR_DWMBASE                  XBPSYSCLR_3DLIGHT
#define XBPSYSCLR_MENUBAR                  (-62)  
#define XBPSYSCLR_HOTLIGHTBGND             (-61)  
#define XBPSYSCLR_GRADIENTACTIVETITLE      (-60) 
#define XBPSYSCLR_GRADIENTINACTIVETITLE    (-59) 
#define XBPSYSCLR_BUTTONTEXT               (-58)
#define XBPSYSCLR_INFOBACKGROUND           (-57)
#define XBPSYSCLR_INFOTEXT                 (-56)
#define XBPSYSCLR_3DHIGHLIGHT              (-55)
#define XBPSYSCLR_3DLIGHT                  (-54)
#define XBPSYSCLR_3DFACE                   (-53)
#define XBPSYSCLR_3DSHADOW                 (-52)
#define XBPSYSCLR_3DDARKSHADOW             (-51)
#define XBPSYSCLR_SHADOWHILITEBGND         (-50)
#define XBPSYSCLR_SHADOWHILITEFGND         (-49)
#define XBPSYSCLR_SHADOWTEXT               (-48)
#define XBPSYSCLR_ENTRYFIELD               (-47)
#define XBPSYSCLR_MENUDISABLEDTEXT         (-46)
#define XBPSYSCLR_MENUHILITE               (-45)
#define XBPSYSCLR_MENUHILITEBGND           (-44)
#define XBPSYSCLR_PAGEBACKGROUND           (-43)
#define XBPSYSCLR_FIELDBACKGROUND          (-42)
#define XBPSYSCLR_BUTTONLIGHT              (-41)
#define XBPSYSCLR_BUTTONMIDDLE             (-40)
#define XBPSYSCLR_BUTTONDARK               (-39)
#define XBPSYSCLR_BUTTONDEFAULT            (-38)
#define XBPSYSCLR_TITLEBOTTOM              (-37)
#define XBPSYSCLR_SHADOW                   (-36)
#define XBPSYSCLR_ICONTEXT                 (-35)
#define XBPSYSCLR_DIALOGBACKGROUND         (-34)
#define XBPSYSCLR_HILITEFOREGROUND         (-33)
#define XBPSYSCLR_HILITEBACKGROUND         (-32)
#define XBPSYSCLR_INACTIVETITLETEXTBGND    (-31)
#define XBPSYSCLR_ACTIVETITLETEXTBGND      (-30)
#define XBPSYSCLR_INACTIVETITLETEXT        (-29)
#define XBPSYSCLR_ACTIVETITLETEXT          (-28)
#define XBPSYSCLR_OUTPUTTEXT               (-27)
#define XBPSYSCLR_WINDOWSTATICTEXT         (-26)
#define XBPSYSCLR_SCROLLBAR                (-25)
#define XBPSYSCLR_BACKGROUND               (-24)
#define XBPSYSCLR_ACTIVETITLE              (-23)
#define XBPSYSCLR_INACTIVETITLE            (-22)
#define XBPSYSCLR_MENU                     (-21)
#define XBPSYSCLR_WINDOW                   (-20)
#define XBPSYSCLR_WINDOWFRAME              (-19)
#define XBPSYSCLR_MENUTEXT                 (-18)
#define XBPSYSCLR_WINDOWTEXT               (-17)
#define XBPSYSCLR_TITLETEXT                (-16)
#define XBPSYSCLR_ACTIVEBORDER             (-15)
#define XBPSYSCLR_INACTIVEBORDER           (-14)
#define XBPSYSCLR_APPWORKSPACE             (-13)
#define XBPSYSCLR_HELPBACKGROUND           (-12)
#define XBPSYSCLR_HELPTEXT                 (-11)
#define XBPSYSCLR_HELPHILITE               (-10)

// Special background color that prevents the background from being 
// overwritten
#define XBPSYSCLR_TRANSPARENT              (-255)


//****************************************************************************
// System font defines, used together with XbpFont
//****************************************************************************

#define XBPSYSFNT_CAPTION                  1
#define XBPSYSFNT_SMALLCAPTION             2
#define XBPSYSFNT_MENU                     3
#define XBPSYSFNT_STATUS                   4
#define XBPSYSFNT_MSGBOX                   5
#define XBPSYSFNT_ICONTITLE                6
#define XBPSYSFNT_GUIDEFAULT               XBPSYSFNT_MSGBOX


//****************************************************************************
// Constants for XbpSLE
//****************************************************************************

// Defines for XbpSLE:Align
#define XBPSLE_LEFT                        1
#define XBPSLE_RIGHT                       2
#define XBPSLE_CENTER                      3


//****************************************************************************
// Constants for XbpCombobox
//****************************************************************************

// Defines for XbpCombobox:Type
#define XBPCOMBO_SIMPLE                    1
#define XBPCOMBO_DROPDOWN                  2
#define XBPCOMBO_DROPDOWNLIST              3


//****************************************************************************
// Constants for XbpListbox
//****************************************************************************

// Defines for XbpListbox:MarkMode
#define XBPLISTBOX_MM_SINGLE               1
#define XBPLISTBOX_MM_MULTIPLE             2
#define XBPLISTBOX_MM_EXTENDED             3


//****************************************************************************
// Constants for XbpClipboard
//****************************************************************************

// Defines for the return value of XbpClipboard:queryFormats()
#ifdef __OS2__
#define XBPCLPBRD_TEXT                     1
#define XBPCLPBRD_BITMAP                   2
#define XBPCLPBRD_METAFILE                 5
#endif

#ifdef __WIN32__
#define XBPCLPBRD_TEXT                     1
#define XBPCLPBRD_BITMAP                   8
#define XBPCLPBRD_UNICODE                  13
#define XBPCLPBRD_METAFILE                 14
#define XBPCLPBRD_FILELIST                 15
#define XBPCLPBRD_LOCALE                   16
#endif


//****************************************************************************
// Constants for XbpMetaFile
//****************************************************************************

// Defines for XbpMetaFile:draw()
#define XBPMETA_DRAW_INITPS                1
#define XBPMETA_DRAW_SCALE                 2
#define XBPMETA_DRAW_DEFAULT               3


//****************************************************************************
// Constants for Xbp3State 
//****************************************************************************

// Defines for Xbp3State:getData()
#define XBP3STATE_UNSELECTED               0
#define XBP3STATE_SELECTED                 1
#define XBP3STATE_IDLE                     2


//****************************************************************************
// Constants for XbpSetting
//****************************************************************************

// Defines for XbpSetting:CaptionAlign
#define XBPSETTING_CAPTION_LEFT           XBPALIGN_LEFT
#define XBPSETTING_CAPTION_RIGHT          XBPALIGN_RIGHT


// Defines for XbpSetting:Options
#define XBPSETTING_TEXT_LEFT              XBPALIGN_LEFT
#define XBPSETTING_TEXT_RIGHT             XBPALIGN_RIGHT
#define XBPSETTING_TEXT_CENTER            XBPALIGN_HCENTER
#define XBPSETTING_TEXT_TOP               XBPALIGN_TOP
#define XBPSETTING_TEXT_VCENTER           XBPALIGN_VCENTER
#define XBPSETTING_TEXT_BOTTOM            XBPALIGN_BOTTOM
#define XBPSETTING_TEXT_WORDBREAK         XBPALIGN_WORDBREAK


//****************************************************************************
// Constants for XbpScrollbar
//****************************************************************************

// Defines for XbpScrollbar:Type
#define XBPSCROLL_HORIZONTAL               1
#define XBPSCROLL_VERTICAL                 2

// Defines for mp1[2] after the event xbeSB_Scroll
// (Scrollbar commands)
#define XBPSB_PREVPOS                      1
#define XBPSB_NEXTPOS                      2
#define XBPSB_PREVPAGE                     3
#define XBPSB_NEXTPAGE                     4
#define XBPSB_SLIDERTRACK                  5
#define XBPSB_ENDTRACK                     6
#define XBPSB_ENDSCROLL                    7


//****************************************************************************
// Konstanten fuer XbpTabPage 
//****************************************************************************

#define XBPTABPAGE_TAB_BOTTOM              2
#define XBPTABPAGE_TAB_TOP                 4


//****************************************************************************
// Constants for XbpCellGroup
//****************************************************************************

// Additional presentation parameter for XbpCellGroup
#define XBP_PP_CGRP_ROWWIDTH               100
#define XBP_PP_CGRP_ROWHEIGHT              101
#define XBP_PP_CGRP_CELLWIDTH              102
#define XBP_PP_CGRP_CELLHEIGHT             103
#define XBP_PP_CGRP_CELLALIGNMENT          104
#define XBP_PP_CGRP_HSEPARATOR             105
#define XBP_PP_CGRP_VSEPARATOR             106
#define XBP_PP_CGRP_FRAMELAYOUT            107
#define XBP_PP_CGRP_HILITEFRAMELAYOUT      108
#define XBP_PP_CGRP_CELLFRAMELAYOUT        109


//****************************************************************************
// Constants for XbpColumn
//****************************************************************************

// Visualisation
#define XBPCOL_TYPE_ICON                   1
#define XBPCOL_TYPE_BITMAP                 2
#define XBPCOL_TYPE_SYSICON                3
#define XBPCOL_TYPE_TEXT                   4
#define XBPCOL_TYPE_FILEICON               5
#define XBPCOL_TYPE_FILEMINIICON           6
#define XBPCOL_TYPE_MULTILINETEXT          7

// Row/Column separator definitions
#define XBPCOL_SEP_NONE                    XBPLINE_NONE
#define XBPCOL_SEP_LINE                    XBPLINE_NORMAL
#define XBPCOL_SEP_DASHED                  XBPLINE_DASHED
#define XBPCOL_SEP_DOTTED                  XBPLINE_DOTTED

// Offsets for the presentation parameter of the DataArea
#define XBPCOL_DA_FGCLR                    1
#define XBPCOL_DA_BGCLR                    2
#define XBPCOL_DA_HILITE_FGCLR             3
#define XBPCOL_DA_HILITE_BGCLR             4
#define XBPCOL_DA_COMPOUNDNAME             5
#define XBPCOL_DA_ROWWIDTH                 6
#define XBPCOL_DA_ROWHEIGHT                7
#define XBPCOL_DA_CELLWIDTH                8
#define XBPCOL_DA_CELLHEIGHT               9
#define XBPCOL_DA_CELLALIGNMENT            10
#define XBPCOL_DA_ROWSEPARATOR             11
#define XBPCOL_DA_COLSEPARATOR             12
#define XBPCOL_DA_FRAMELAYOUT              13
#define XBPCOL_DA_CELLFRAMELAYOUT          14
#define XBPCOL_DA_HILITEFRAMELAYOUT        15
#define XBPCOL_DA_CHARWIDTH                16

#define XBPCOL_DA_COUNT                    16

// Offsets for the presentation parameter of Heading/Footing
#define XBPCOL_HFA_FGCLR                   1
#define XBPCOL_HFA_BGCLR                   2
#define XBPCOL_HFA_COMPOUNDNAME            3
#define XBPCOL_HFA_FRAMELAYOUT             4
#define XBPCOL_HFA_ALIGNMENT               5
#define XBPCOL_HFA_HEIGHT                  6
#define XBPCOL_HFA_CAPTION                 7

#define XBPCOL_HFA_COUNT                   7

// Additional presentation parameter for XbpColumn (also valid
// for XbpBrowse)
#define XBP_PP_COL_DA_BASE                 100
#define XBP_PP_COL_DA_FGCLR                (XBP_PP_COL_DA_BASE+XBPCOL_DA_FGCLR)
#define XBP_PP_COL_DA_BGCLR                (XBP_PP_COL_DA_BASE+XBPCOL_DA_BGCLR)
#define XBP_PP_COL_DA_HILITE_FGCLR         (XBP_PP_COL_DA_BASE+XBPCOL_DA_HILITE_FGCLR)
#define XBP_PP_COL_DA_HILITE_BGCLR         (XBP_PP_COL_DA_BASE+XBPCOL_DA_HILITE_BGCLR)
#define XBP_PP_COL_DA_COMPOUNDNAME         (XBP_PP_COL_DA_BASE+XBPCOL_DA_COMPOUNDNAME)
#define XBP_PP_COL_DA_ROWWIDTH             (XBP_PP_COL_DA_BASE+XBPCOL_DA_ROWWIDTH)
#define XBP_PP_COL_DA_ROWHEIGHT            (XBP_PP_COL_DA_BASE+XBPCOL_DA_ROWHEIGHT)
#define XBP_PP_COL_DA_CELLWIDTH            (XBP_PP_COL_DA_BASE+XBPCOL_DA_CELLWIDTH)
#define XBP_PP_COL_DA_CELLHEIGHT           (XBP_PP_COL_DA_BASE+XBPCOL_DA_CELLHEIGHT)
#define XBP_PP_COL_DA_CELLALIGNMENT        (XBP_PP_COL_DA_BASE+XBPCOL_DA_CELLALIGNMENT)
#define XBP_PP_COL_DA_ROWSEPARATOR         (XBP_PP_COL_DA_BASE+XBPCOL_DA_ROWSEPARATOR)
#define XBP_PP_COL_DA_COLSEPARATOR         (XBP_PP_COL_DA_BASE+XBPCOL_DA_COLSEPARATOR)
#define XBP_PP_COL_DA_FRAMELAYOUT          (XBP_PP_COL_DA_BASE+XBPCOL_DA_FRAMELAYOUT)
#define XBP_PP_COL_DA_CELLFRAMELAYOUT      (XBP_PP_COL_DA_BASE+XBPCOL_DA_CELLFRAMELAYOUT)
#define XBP_PP_COL_DA_HILITEFRAMELAYOUT    (XBP_PP_COL_DA_BASE+XBPCOL_DA_HILITEFRAMELAYOUT)
#define XBP_PP_COL_DA_CHARWIDTH            (XBP_PP_COL_DA_BASE+XBPCOL_DA_CHARWIDTH)

#define XBP_PP_COL_HA_BASE                 (XBP_PP_COL_DA_BASE+XBPCOL_DA_COUNT)
#define XBP_PP_COL_HA_FGCLR                (XBP_PP_COL_HA_BASE+XBPCOL_HFA_FGCLR)
#define XBP_PP_COL_HA_BGCLR                (XBP_PP_COL_HA_BASE+XBPCOL_HFA_BGCLR)
#define XBP_PP_COL_HA_COMPOUNDNAME         (XBP_PP_COL_HA_BASE+XBPCOL_HFA_COMPOUNDNAME)
#define XBP_PP_COL_HA_FRAMELAYOUT          (XBP_PP_COL_HA_BASE+XBPCOL_HFA_FRAMELAYOUT)
#define XBP_PP_COL_HA_ALIGNMENT            (XBP_PP_COL_HA_BASE+XBPCOL_HFA_ALIGNMENT)
#define XBP_PP_COL_HA_HEIGHT               (XBP_PP_COL_HA_BASE+XBPCOL_HFA_HEIGHT)
#define XBP_PP_COL_HA_CAPTION              (XBP_PP_COL_HA_BASE+XBPCOL_HFA_CAPTION)

#define XBP_PP_COL_FA_BASE                 (XBP_PP_COL_HA_BASE+XBPCOL_HFA_COUNT)
#define XBP_PP_COL_FA_FGCLR                (XBP_PP_COL_FA_BASE+XBPCOL_HFA_FGCLR)
#define XBP_PP_COL_FA_BGCLR                (XBP_PP_COL_FA_BASE+XBPCOL_HFA_BGCLR)
#define XBP_PP_COL_FA_COMPOUNDNAME         (XBP_PP_COL_FA_BASE+XBPCOL_HFA_COMPOUNDNAME)
#define XBP_PP_COL_FA_FRAMELAYOUT          (XBP_PP_COL_FA_BASE+XBPCOL_HFA_FRAMELAYOUT)
#define XBP_PP_COL_FA_ALIGNMENT            (XBP_PP_COL_FA_BASE+XBPCOL_HFA_ALIGNMENT)
#define XBP_PP_COL_FA_HEIGHT               (XBP_PP_COL_FA_BASE+XBPCOL_HFA_HEIGHT)
#define XBP_PP_COL_FA_CAPTION              (XBP_PP_COL_FA_BASE+XBPCOL_HFA_CAPTION)


//****************************************************************************
// Constants for XbpBrowse
//****************************************************************************

// Cursor mode
#define XBPBRW_CURSOR_NONE                 1
#define XBPBRW_CURSOR_CELL                 2
#define XBPBRW_CURSOR_ROW                  3

// Navigation mode
#define XBPBRW_NAVIGATION_SYSTEM           1
#define XBPBRW_NAVIGATION_1XCOMPATIBLE     2

// Compatiblity/behavior
#define XBPBRW_BEHAVIOR_DEFAULT            0 
#define XBPBRW_BEHAVIOR_1X                 355

// Message parameter definitions for XbpBrowse specific events

// xbeBRW_Navigate->MsgPar1:
#define XBPBRW_Navigate_NextLine           1
#define XBPBRW_Navigate_PrevLine           2
#define XBPBRW_Navigate_NextPage           3
#define XBPBRW_Navigate_PrevPage           4
#define XBPBRW_Navigate_GoTop              5
#define XBPBRW_Navigate_GoBottom           6
#define XBPBRW_Navigate_Skip               7    // MsgPar2 == <nSkip>
#define XBPBRW_Navigate_NextCol            8
#define XBPBRW_Navigate_PrevCol            9
#define XBPBRW_Navigate_FirstCol           10
#define XBPBRW_Navigate_LastCol            11
#define XBPBRW_Navigate_GoPos              12  // MsgPar2 == <nNewPercentPos>
// XbpBrowse only
#define XBPBRW_Navigate_SkipCols           13  // MsgPar2 == <nColsToSkip>
// XbpQuickbrowse only
#define XBPBRW_Navigate_GotoItem           14  // MsgPar2 == <aRowCol>
#define XBPBRW_Navigate_GotoRecord         15  // MsgPar2 == <nRecordId>


// xbeBRW_Pan->MsgPar1:
#define XBPBRW_Pan_Left                    1
#define XBPBRW_Pan_Right                   2
#define XBPBRW_Pan_FirstCol                3
#define XBPBRW_Pan_LastCol                 4
#define XBPBRW_Pan_Track                   5


// xbeBRW_Scroll->MsgPar1:
#define XBPBRW_Scroll_Up                   XBPBRW_Navigate_PrevLine
#define XBPBRW_Scroll_Down                 XBPBRW_Navigate_NextLine
#define XBPBRW_Scroll_PageUp               XBPBRW_Navigate_PrevPage
#define XBPBRW_Scroll_PageDown             XBPBRW_Navigate_NextPage
#define XBPBRW_Scroll_Bottom               XBPBRW_Navigate_GoBottom
#define XBPBRW_Scroll_Top                  XBPBRW_Navigate_GoTop
#define XBPBRW_Scroll_Pos                  XBPBRW_Navigate_GoPos
#define XBPBRW_Scroll_Track                XBPBRW_Navigate_Skip


//****************************************************************************
// Constants for XbpBitmap 
//****************************************************************************

// Bitmap formats supported
#define XBPBMP_FORMAT_WIN2X                256
#define XBPBMP_FORMAT_WIN3X                512
#define XBPBMP_FORMAT_OS21X                XBPBMP_FORMAT_WIN2X
#define XBPBMP_FORMAT_OS22X                1024
#define XBPBMP_FORMAT_GIF                  4096
#define XBPBMP_FORMAT_JPG                  8192
#define XBPBMP_FORMAT_PNG                  16384
#define XBPBMP_FORMAT_TIFF                 32768
#define XBPBMP_FORMAT_JPGXR                131072
#define XBPBMP_FORMAT_DNG                  262144

#define XBPBMP_FORMAT_FILE                 65536

#ifdef __WIN32__
#define XBPBMP_FORMAT_DEFAULT              XBPBMP_FORMAT_WIN3X
#define XBPBMP_FORMAT_BMP                  (XBPBMP_FORMAT_WIN3X+XBPBMP_FORMAT_FILE)
#endif
#ifdef __OS2__
#define XBPBMP_FORMAT_DEFAULT              XBPBMP_FORMAT_OS22X
#define XBPBMP_FORMAT_BMP                  (XBPBMP_FORMAT_OS22X+XBPBMP_FORMAT_FILE)
#endif

// Bitmap Compression
#define XBPBMP_DEF_COMPRESSION             -1


//****************************************************************************
// Constants for XbpPrintDialog 
//****************************************************************************
// Dialog Mode
#define  XBPPDLG_MODE_DRIVER               1
#define  XBPPDLG_MODE_APPLICATION          2

// Print Range Identifiers
#define  XBPPDLG_PRINT_MARK                1
#define  XBPPDLG_PRINT_ALLPAGES            2
#define  XBPPDLG_PRINT_PAGERANGE           3


//****************************************************************************
// Constants for XbpColorDialog
//****************************************************************************
// Dialog Mode
#define XBPCDLG_MODE_ALLOWCOLOREDIT        0
#define XBPCDLG_MODE_EDITCOLORS            1
#define XBPCDLG_MODE_NOCOLOREDIT           2


//****************************************************************************
// Constants for XbpFontDialog
//****************************************************************************
// Code page (character set) selection
#define XBPFDLG_CODEPAGE_SYSDEFAULT  0
#define XBPFDLG_CODEPAGE_SELECT      1
#define XBPFDLG_CODEPAGE_KEEP        2



//****************************************************************************
// Constants for XbpSpinButton
//****************************************************************************
// Dialog Mode
#define XBPSPIN_NUM_DECIMAL                0
#define XBPSPIN_NUM_HEX                    1
#define XBPSPIN_NUM_HEXUPPERCASE           2
#define XBPSPIN_NUM_OCTAL                  3


//****************************************************************************
// Constants for XbpSplitBar
//****************************************************************************
// Splitbar orientation
#define XBPSPLITBAR_HORIZONTAL             0
#define XBPSPLITBAR_VERTICAL               1


//****************************************************************************
// Constants for DragDataObject 
//****************************************************************************
// Defines for specifying aspect/representation
// of the data in a drag-and-drop operation
#define DRAGDATAOBJECT_ASPECT_CONTENT   1
#define DRAGDATAOBJECT_ASPECT_THUMBNAIL 2
#define DRAGDATAOBJECT_ASPECT_ICON      4

// Defines for specifying storage media for
// the data of a drag-and-drop operation
#define DRAGDATAOBJECT_MEDIA_NULL        0
#define DRAGDATAOBJECT_MEDIA_MEMORY      1
#define DRAGDATAOBJECT_MEDIA_FILE        2
#define DRAGDATAOBJECT_MEDIA_STREAM      4
#define DRAGDATAOBJECT_MEDIA_METAFILE    64


//****************************************************************************
// Constants for the return value of AppType()
// The #defines are like the linker options /PM:<type> of Link386
//****************************************************************************

#define APPTYPE_NOVIO                      1
#define APPTYPE_VIO                        2
#define APPTYPE_PM                         3


//****************************************************************************
// Constants for ConfirmBox()
//****************************************************************************

#ifdef __OS2__

// Configuration of pushbuttons
#define XBPMB_OK                           0
#define XBPMB_OKCANCEL                     1
#define XBPMB_RETRYCANCEL                  2
#define XBPMB_ABORTRETRYIGNORE             3
#define XBPMB_YESNO                        4
#define XBPMB_YESNOCANCEL                  5
#define XBPMB_CANCEL                       6
#define XBPMB_ENTER                        7
#define XBPMB_ENTERCANCEL                  8

// Defines for the style
#define XBPMB_NOICON                       0
#define XBPMB_QUESTION                     16
#define XBPMB_WARNING                      32
#define XBPMB_INFORMATION                  48
#define XBPMB_CRITICAL                     64

#define XBPMB_APPMODAL                     0
#define XBPMB_SYSMODAL                     4096
#define XBPMB_MOVEABLE                     16384

// Defbutton
#define XBPMB_DEFBUTTON1                   0
#define XBPMB_DEFBUTTON2                   256
#define XBPMB_DEFBUTTON3                   512

// Confirm box return codes
#define XBPMB_RET_OK                       1
#define XBPMB_RET_CANCEL                   2
#define XBPMB_RET_ABORT                    3
#define XBPMB_RET_RETRY                    4
#define XBPMB_RET_IGNORE                   5
#define XBPMB_RET_YES                      6
#define XBPMB_RET_NO                       7
#define XBPMB_RET_ENTER                    9
#define XBPMB_RET_ERROR                    65535

#endif

#ifdef __WIN32__

// Configuration of pushbuttons
#define XBPMB_OK                           0
#define XBPMB_OKCANCEL                     1
#define XBPMB_RETRYCANCEL                  5
#define XBPMB_ABORTRETRYIGNORE             2
#define XBPMB_YESNO                        4
#define XBPMB_YESNOCANCEL                  3
#define XBPMB_CANCEL                       0
#define XBPMB_ENTER                        0
#define XBPMB_ENTERCANCEL                  1
#define XBPMB_HELP                         16384

// Defines for the style
#define XBPMB_NOICON                       0
#define XBPMB_QUESTION                     32
#define XBPMB_WARNING                      48
#define XBPMB_INFORMATION                  64
#define XBPMB_CRITICAL                     16

#define XBPMB_APPMODAL                     (0 + 65536)
#define XBPMB_SYSMODAL                     (4096 + 65536)
#define XBPMB_MOVEABLE                     65536

// Defbutton
#define XBPMB_DEFBUTTON1                   0
#define XBPMB_DEFBUTTON2                   256
#define XBPMB_DEFBUTTON3                   512

// Confirm box return codes
#define XBPMB_RET_OK                       1
#define XBPMB_RET_CANCEL                   2
#define XBPMB_RET_ABORT                    3
#define XBPMB_RET_RETRY                    4
#define XBPMB_RET_IGNORE                   5
#define XBPMB_RET_YES                      6
#define XBPMB_RET_NO                       7
#define XBPMB_RET_ENTER                    9
#define XBPMB_RET_ERROR                    65535

#endif

// Xbp.ch is included
#define  _XBP_CH

#endif // #ifndef _XBP_CH

// * EOF *
