//////////////////////////////////////////////////////////////////////
//
//  XBT.CH
//
//  Copyright:
//      Alaska Software, (c) 1996-2023. All rights reserved.         
//  
//  Contents:
//      Global compatibility definitions for the XbTools-III
//   
//////////////////////////////////////////////////////////////////////


#ifndef _XBT_CH          // XBT.CH not yet loaded
#define _XBT_CH          // This prevents multiple includes

//////
//
// CSETKEY()
//
// The command SET KEY is in Xbase++ translated into a call of the function
// SetKey(). The following preprocessor commands are use to preserve the
// compatiblity to the Clipper-Tools. By overloading the original definitions
// of Xbase++ the Keyboard-Code and the function-name will be saved into
// a special storage area of the XbTools. This enables the Tools-functions
// cSetKey() to return these informations.
//
// IMPORTANT NOTE:
//    This functions should not be used in new applications!
//

#command  SET KEY <nInkey> TO <proc> ;
      =>  SetKey(<nInkey>, {|pn,pl,vn| <proc>(pn,pl,vn)}) ;
        ; CSETKEY(<nInkey>, <(proc)>)

#command  SET KEY <nInkey> TO <proc:&> ;
      =>  if ( Empty(<(proc)>) ) ;;
             SetKey(<nInkey>, NIL) ; CSETKEY(<nInkey>, "") ;;
          else ;;
             SetKey(<nInkey>, {|pn,pl,vn| <proc>(pn,pl,vn)}) ;;
             CSETKEY(<nInkey>, <(proc)>) ;;
          endif

#command  SET KEY <nInkey> [TO] ;
      =>  SetKey(<nInkey>, NIL) ; CSETKEY(<nInkey>, "")


//////
//
// The following #command definitions are needed for the XbTools function
// cSetRDONLY(). The keyword READONLY of the USE command takes precedence
// over the cSetRDONLY() function. Without the READONLY keyword the mode
// defined with cSetRDONLY() will be used.
//
// Example:
//
// #include "XBT.CH"
//
// USE LAGER READONLY
// USE LAGER
//
// This will result in the following code:
//
// dbUseArea( .F.,, "LAGER",, if(.F. .OR. .F., !.F., NIL), .T. )
// dbUseArea( .F.,, "LAGER",, if(.F. .OR. .F., !.F., NIL), CSETRDONLY() )
//

#command  USE <(dbFile)> ;
              [VIA <dbe>] ;
                  [ALIAS <alias>] ;
              [<new: NEW>] ;
              [<exc: EXCLUSIVE>] ;
              [<sha: SHARED>] ;
              [INDEX <(index1)> [, <(indexN)>]] ;
      =>  dbUseArea( <.new.>, <(dbe)>, <(dbFile)>, <(alias)>, ;
                    iif(<.sha.> .or. <.exc.>, !<.exc.>, NIL), CSetRDONLY()) ;
          [; dbSetIndex( <(index1)> )] [; dbSetIndex( <(indexN)> )]


#endif                         // #ifndef _XBT_CH
// * EOF *
