//////////////////////////////////////////////////////////////////////
//
//  XBTCOM.CH
//
//  Copyright:
//      Alaska Software, (c) 1996-2023. All rights reserved.         
//  
//  Contents:
//      Definitions for XbTools-III serial communication.
//   
//////////////////////////////////////////////////////////////////////


#ifndef _XBTCOM_CH_
#define _XBTCOM_CH_

/*
 * Definitions for COM_OPEN()
 */
#define COM_OPEN_FASTUART   1       // Used for 16550 UARTS to enable
                                    // Extended Hardware Buffering
#define COM_OPEN_NOINIT     2       // COM Port will not be initialized

/*
 * Definitions for COM_CLOSE()
 */
#define COM_CLOSE_NOFLUSH   1       // COM Port will not be flushed before
                                    // it is closed.

/*
 * Definitions for COM_EVENT()
 */                                  
#define COM_EVENT_CHAR      1       // Character arrived at COM port
#define COM_EVENT_CTSDSR    2       // CTS or DSR changed
#define COM_EVENT_ERROR     3       // Line status error occurred (overrun, parity or break)
#define COM_EVENT_RING      4       // Ring indicator detected


/*
 * Definitions for COM_LSR()
 */
#define LSR_ERROR           0       // Parameter Error
#define LSR_DATA_READY      1       // Data Ready
#define LSR_OVERRUN_ERR     2       // Overrun Error
#define LSR_PARITY_ERR      4       // Parity Error
#define LSR_FRAMING_ERR     8       // Framing Error
#define LSR_BREAK           16      // Break Interrupt

/*
 * Definitions for COM_MSR()
 */
#define MSR_ERROR           0       // Parameter Error
#define MSR_DELTA_CTS       1       // CTS changed
#define MSR_DELTA_DSR       2       // DSR changed
#define MSR_TERI            4       // RI changed
#define MSR_DELTA_DCD       8       // DCD changed
#define MSR_CTS             16      // Clear To Send
#define MSR_DSR             32      // Data Set Ready
#define MSR_RI              64      // Ring Indicator
#define MSR_DCD             128     // Data Carrier Detect

/*
 * Definitions for COM_MCR()
 */
#define MCR_ERROR           0       // Parameter Error
#define MCR_DTR             1       // Data Terminal Ready
#define MCR_RTS             2       // Request To Send

/*
 * Definitions for COM_SMODE()
 */
#define SMODE_ERROR         0       // Parameter Error
#define SMODE_EMPTY         1       // Transmit buffer empty
#define SMODE_SOFT          2       // Waiting for XON
#define SMODE_HARD          4       // Waiting for CTS (DSR or DCD)

/*
 * Definitions for COM_CRC()
 */
#define Parity              3       // 2^1 + 1
#define LCR_8               257     // 2^8 + 1
#define CRC_12              5011    // 2^12 + 2^11 + 2^3 + 2^2 + 2^1 + 1
#define CRC_16_X25          69665   // 2^16 + 2^12 + 2^5 + 1
#define CRC_16              98309   // 2^16 + 2^15 + 2^2 + 1


/*
 * Definitions for COM_READMODE
 */
#define NO_WAIT_READ_TIMEOUT    0   // Do not wait if no data is available.
#define READ_TIMEOUT            1   // Normal timeout processing.
#define WAIT_READ_TIMEOUT       2   // Wait timeout processing (see doc.)

/*
 * Definitions for COM_SENDMODE
 */
#define WRITE_TIMEOUT           0   // Normal write timeout processing
#define INFINITE_WRITE_TIMEOUT  1   // Wait until all data has been sent.


/*
 * Definitions not supported by XbTools.
 */
#ifdef __XPP__
#xtrans LSR_TRANS_HOLD_EMPTY    =>  #error LSR_TRANS_HOLD_EMPTY not supported
#xtrans LSR_TRANS_EMPTY         =>  #error LSR_TRANS_EMPTY not supported
#xtrans MCR_OUT_1               =>  #error MCR_OUT_1 not supported
#xtrans MCR_OUT_2               =>  #error MCR_OUT_2 not supported
#xtrans MCR_LOOP                =>  #error MCR_LOOP not supported
#xtrans SMODE_RFLUSH            =>  #error SMODE_RFLUSH not supported
#endif

#endif

