//////////////////////////////////////////////////////////////////////
//
//  XPP-CFG.CH
//
//  Copyright:
//   Alaska Software, (c) 1998-2023. All rights reserved.         
//  
//  ----------------------- !!WARNING!! -----------------------
//  INCORRECT CONFIGURATION SETTINGS CAN SEVERELY IMPACT THE
//  STABILITY OF YOUR APPLICATION! PLEASE CONTACT ALASKA
//  SOFTWARE PRIOR TO CHANGING ANY OF THE VALUES DEFINED BELOW!
//  ----------------------- !!WARNING!! -----------------------
//
//  String resource IDs for the Xbase++ runtime configuration.
//  
//  The associated string value must begin with a prefix in 
//  lowercase letters. The prefix consists of the string "xpp-"  
//  followed by the type of the value and a colon.
//  
//  The syntax is:
//  
//  xpp-<type>:<cConfigurationValue>
//  
//  If a string value associated with a resource ID does not 
//  have the expected format and type, the default value for 
//  the setting is used. For compatibility reasons, no error is
//  generated.
//
//  Integer values can be specified in decimal (123), binary
//  (0b1111011) and hexadecimal (0x7b) notation.
//  
//////////////////////////////////////////////////////////////////////


#ifndef __XPP_CFG_CH_
#define __XPP_CFG_CH_

#define XPP_CFG_MAX 16384

/// <summary>
/// Defines the 32 bit processor affinity mask for the process.
/// If more than one bit is set, the runtime will automatically
/// switch to multi-core-usage. Using multiple cores at once does
/// not automatically lead to performance gains because the cores
/// typically share memory and disk.
/// </summary>
/// <note>
/// - type: integer
/// </note>
/// <note>
/// - Default: XPP_CFG_PROCAFFINITY = "xpp-integer:0b1"
/// </note>
#define XPP_CFG_PROCAFFINITY     XPP_CFG_MAX - 1

/// <summary>
/// Defines the number of available memory object handles.
/// The value "0" corresponds to the standard configuration of
/// approximately 2 million handles.
/// </summary>
/// <note>
/// - Type: integer
/// </note>
/// <note>
/// - Default: XPP_CFG_MOM_HANDLESPACE = "xpp-integer:0"
/// </note>
#define XPP_CFG_MOM_HANDLESPACE  XPP_CFG_MAX - 2

/// <summary>
/// Defines the requested size of the linear address space
/// available to the memory manager in Kilobyte. If the value
/// is "0", the runtime allocates about 2/3 of the available
/// memory. If the value is too low for an application, an
/// out of memory error is raised.
/// </summary>
/// <note>
/// - Type: integer in kB
/// </note>
/// <note>
/// - Default: XPP_CFG_MOM_MEMORYSPACE = "xpp-integer:0"
/// </note>
#define XPP_CFG_MOM_MEMORYSPACE  XPP_CFG_MAX - 3

/// <summary>
/// Sets the behavior of the C-Api functions. If the value is
/// "1", the behavior corresponds to the Xbase++ version 1.9.
/// </summary>
/// <note>
/// - Type: integer
/// </note>
/// <note>
/// - Default: XPP_CFG_CAPI_BEHAVIOR = "xpp-integer:0"
/// </note>
#define XPP_CFG_CAPI_BEHAVIOR    XPP_CFG_MAX - 4

/// <summary>
/// Defines the control word of the floating point unit (FPU).
/// The control word determines the behavior of the floating
/// point exceptions, the precision and the rounding behavior.
/// </summary>
/// <note>
/// - Type: integer
/// </note>
/// <note>
/// - Default: XPP_CFG_FPU_CONTROLWORD = "xpp-integer:0x332"
/// </note>
#define XPP_CFG_FPU_CONTROLWORD  XPP_CFG_MAX - 5

#endif // __XPP_CFG_CH_
