#!/usr/bin/env python3
import sys
import argparse
import os
import csv
import json
import io

def import_csv(infile, outfile='', delimiter=',', quote='"', json_out=True):

    suffix = '.json' if json_out else '.txt'
    if not outfile:
        outfile = os.path.splitext(infile)[0]+suffix

    csv_list = []
    with open(infile) as csvfile:
        csvreader = csv.reader(csvfile, delimiter=str(delimiter.strip()), quotechar=str(quote.strip()))
        try:
            for row in csvreader:
                csv_list.append(row)
        except Exception as e:
            print(e)

    with open(outfile, 'w') as outfile:
        if json_out:
            json.dump(csv_list, outfile, ensure_ascii=False, indent=2)    
        else:
            data = ''
            for row in csv_list:
                data += '\t'.join(row) + '\n'
            outfile.write(data)


if __name__ == '__main__':
    parser = argparse.ArgumentParser()
    parser.add_argument('-d', '--delimiter', help="CSV field delimiter")
    parser.add_argument('-q', '--quote', help="Quote character")
    parser.add_argument('-t', '--text', action='store_true', help="Text output instead json")
    parser.add_argument('-o', '--file_out', help="Output file name")
    parser.add_argument('file_in', help="Input file name")
    args = parser.parse_args()
    if not args.file_out:
        args.file_out = ''
    if not args.delimiter:
        args.delimiter = ''
    if not args.quote:
        args.quote = ''

    import_csv(args.file_in, 
               args.file_out.strip(),
               args.delimiter.strip(),
               args.quote.strip(),
               not args.text
               )
